@@ -2,5 +2,6 @@ var Chain_8h =
 [
     [ "Chain", "classIMP_1_1atom_1_1Chain.html", "classIMP_1_1atom_1_1Chain" ],
     [ "Chains", "Chain_8h.html#a638afd5b948fe275c3aaf6652592b264", null ],
-    [ "get_chain", "Chain_8h.html#a13fb268fe2be9e83bbd9a1a2197499ef", null ]
+    [ "get_chain", "Chain_8h.html#a13fb268fe2be9e83bbd9a1a2197499ef", null ],
+    [ "get_chain_id", "Chain_8h.html#a46482205ec4626a8fb4800a6bce46af7", null ]
 ];
\ No newline at end of file
