@@ -1,17 +1,18 @@
 var atom_2Hierarchy_8h =
 [
     [ "Hierarchy", "classIMP_1_1atom_1_1Hierarchy.html", "classIMP_1_1atom_1_1Hierarchy" ],
-    [ "IMP_CAPS_NAME", "atom_2Hierarchy_8h.html#a7197b2337ad319c4df9f1c8edcfc3afb", null ],
-    [ "IMP_FOREACH_HIERARCHY_TYPE_FUNCTIONS", "atom_2Hierarchy_8h.html#aee0fa70474b79c122c90a2a9f5cdd92d", null ],
-    [ "IMP_FOREACH_HIERARCHY_TYPE_LIST", "atom_2Hierarchy_8h.html#a269690c2144914bba70a98d62504e28b", null ],
-    [ "IMP_FOREACH_HIERARCHY_TYPE_STATEMENTS", "atom_2Hierarchy_8h.html#ac34191c88a65443491aecd173f4af681", null ],
-    [ "IMP_GET_AS_DECL", "atom_2Hierarchy_8h.html#aa929cd4c58f48935f030b6dee073058c", null ],
-    [ "IMP_GET_AS_DEF", "atom_2Hierarchy_8h.html#a4d8f247159e7fe7ab9e50f08533a2634", null ],
+    [ "IMP_ATOM_CAPS_NAME", "atom_2Hierarchy_8h.html#aac124b65214a65bdb28bf7d78d80c7e0", null ],
+    [ "IMP_ATOM_FOREACH_HIERARCHY_TYPE_FUNCTIONS", "atom_2Hierarchy_8h.html#a607e352fb82c4e21bf7932648208d295", null ],
+    [ "IMP_ATOM_FOREACH_HIERARCHY_TYPE_LIST", "atom_2Hierarchy_8h.html#ab5f14811a5ff668e22805e2c2cb7ceda", null ],
+    [ "IMP_ATOM_FOREACH_HIERARCHY_TYPE_STATEMENTS", "atom_2Hierarchy_8h.html#ac40833e7b9a17d0c886d7d4e029d3536", null ],
+    [ "IMP_ATOM_GET_AS_DECL", "atom_2Hierarchy_8h.html#a13541f4c7ecb030110a4f5a24c5a017b", null ],
+    [ "IMP_ATOM_GET_AS_DEF", "atom_2Hierarchy_8h.html#a5e5b8d06be62a7227b6afb142661f9bc", null ],
     [ "Hierarchies", "atom_2Hierarchy_8h.html#a3e644ff867fb368a6c7715b234e52b2d", null ],
     [ "GetByType", "atom_2Hierarchy_8h.html#abbe974bcb01d2f1dc86b33fd48a76fc4", [
       [ "ATOM_TYPE", "atom_2Hierarchy_8h.html#abbe974bcb01d2f1dc86b33fd48a76fc4a77a33ac8bbc5816aabaa1cb5dbd8b198", null ],
       [ "RESIDUE_TYPE", "atom_2Hierarchy_8h.html#abbe974bcb01d2f1dc86b33fd48a76fc4a043eecd0d5722ad0f3b138a6a2bd9340", null ],
       [ "CHAIN_TYPE", "atom_2Hierarchy_8h.html#abbe974bcb01d2f1dc86b33fd48a76fc4a110526e1f7207f7872ad6662b3cdbda9", null ],
+      [ "MOLECULE_TYPE", "atom_2Hierarchy_8h.html#abbe974bcb01d2f1dc86b33fd48a76fc4ab8edceafa556ccf89c887fedc870c679", null ],
       [ "DOMAIN_TYPE", "atom_2Hierarchy_8h.html#abbe974bcb01d2f1dc86b33fd48a76fc4a925a0ca0fa321cb12bfc0bb01c1f4bb6", null ],
       [ "FRAGMENT_TYPE", "atom_2Hierarchy_8h.html#abbe974bcb01d2f1dc86b33fd48a76fc4a9b292109aa223e185f529d02221b05bf", null ],
       [ "XYZ_TYPE", "atom_2Hierarchy_8h.html#abbe974bcb01d2f1dc86b33fd48a76fc4a880ff6e0acabdd2144cd1f3b5a172567", null ],
