@@ -1,13 +1,9 @@
 var base_2deprecation__macros_8h =
 [
-    [ "IMP_DEPRECATED_CLASS", "base_2deprecation__macros_8h.html#a5c37bc05b757c197b6523109ea2acd11", null ],
-    [ "IMP_DEPRECATED_FUNCTION", "base_2deprecation__macros_8h.html#af5905caf8d48e030db4ba62eb123d9cc", null ],
     [ "IMP_DEPRECATED_FUNCTION_DEF", "base_2deprecation__macros_8h.html#a166f322cdab8c291293cd92ebc1afa75", null ],
     [ "IMP_DEPRECATED_FUNCTION_RUNTIME_WARNING", "base_2deprecation__macros_8h.html#a6788edb6e6b518713eb0a80425b09865", null ],
     [ "IMP_DEPRECATED_MACRO", "base_2deprecation__macros_8h.html#a632db269a38a6a377edd72f883870490", null ],
     [ "IMP_DEPRECATED_METHOD_RUNTIME_WARNING", "base_2deprecation__macros_8h.html#ad84eeb48aefd463e1fe9285721e0b050", null ],
-    [ "IMP_DEPRECATED_OBJECT", "base_2deprecation__macros_8h.html#abc6489b1eb8c7ac15d49e1a80d6f1328", null ],
     [ "IMP_DEPRECATED_OBJECT_RUNTIME_WARNING", "base_2deprecation__macros_8h.html#aa90763859884ae8419473555587f5e03", null ],
-    [ "IMP_DEPRECATED_VALUE_RUNTIME_WARNING", "base_2deprecation__macros_8h.html#ad267dac4966a84b78cb3827de0ddd67c", null ],
-    [ "IMP_DEPRECATED_WARN", "base_2deprecation__macros_8h.html#a28a380b08502483cb03e466f0cd490ab", null ]
+    [ "IMP_DEPRECATED_VALUE_RUNTIME_WARNING", "base_2deprecation__macros_8h.html#ad267dac4966a84b78cb3827de0ddd67c", null ]
 ];
\ No newline at end of file
