@@ -2,6 +2,5 @@ var base_2ref__counted__macros_8h =
 [
     [ "IMP_REF_COUNTED_DESTRUCTOR", "base_2ref__counted__macros_8h.html#a63d1d56bca849658d8ff97a2d8d2dabe", null ],
     [ "IMP_REF_COUNTED_INLINE_DESTRUCTOR", "base_2ref__counted__macros_8h.html#a23d038af73d3042fb57e7dc536f18c58", null ],
-    [ "IMP_REF_COUNTED_NONTRIVIAL_DESTRUCTOR", "base_2ref__counted__macros_8h.html#a9c4c4588d7e73c39f4d40af1be6477c1", null ],
-    [ "IMP_REF_COUNTED_NONTRIVIAL_VIRTUAL_DESTRUCTOR", "base_2ref__counted__macros_8h.html#a50a6924ba9cf29467dc21c8994cf6da7", null ]
+    [ "IMP_REF_COUNTED_NONTRIVIAL_DESTRUCTOR", "base_2ref__counted__macros_8h.html#a9c4c4588d7e73c39f4d40af1be6477c1", null ]
 ];
\ No newline at end of file
