@@ -1,9 +1,12 @@
 var classIMP_1_1algebra_1_1Ellipsoid3D =
 [
     [ "Ellipsoid3D", "classIMP_1_1algebra_1_1Ellipsoid3D.html#a729122b70edd14aebaa2d5954f44f1e5", null ],
+    [ "Ellipsoid3D", "classIMP_1_1algebra_1_1Ellipsoid3D.html#a4e9bc6c671de9b3e82ecd7680e567a28", null ],
     [ "Ellipsoid3D", "classIMP_1_1algebra_1_1Ellipsoid3D.html#a5dad9047d0e92873b41b9153cc768ca9", null ],
     [ "get_center", "classIMP_1_1algebra_1_1Ellipsoid3D.html#a92bf25280919442617ff72439bb59d42", null ],
+    [ "get_radii", "classIMP_1_1algebra_1_1Ellipsoid3D.html#a4375d8f9f05cd2ed58107ecab00de85f", null ],
     [ "get_radius", "classIMP_1_1algebra_1_1Ellipsoid3D.html#a9addfa212b5925926be8ab70f55cd205", null ],
+    [ "get_reference_frame", "classIMP_1_1algebra_1_1Ellipsoid3D.html#a64cdd46002ef8528e8583d5de98b749a", null ],
     [ "get_rotation", "classIMP_1_1algebra_1_1Ellipsoid3D.html#ab7b41bd7f224e14be6505a9871c2a078", null ],
     [ "get_transformation", "classIMP_1_1algebra_1_1Ellipsoid3D.html#af697d30feba4be5d1e03bb325696e577", null ],
     [ "show", "classIMP_1_1algebra_1_1Ellipsoid3D.html#aa873c34dd7dfd9027d850d95680945fb", null ]
