@@ -1,6 +1,7 @@
 var classIMP_1_1algebra_1_1Transformation3D =
 [
     [ "Transformation3D", "classIMP_1_1algebra_1_1Transformation3D.html#a06edb05ffed07cf63af15f1fa4985f76", null ],
+    [ "Transformation3D", "classIMP_1_1algebra_1_1Transformation3D.html#a0f2df89b87c067870907e1cf5103e036", null ],
     [ "Transformation3D", "classIMP_1_1algebra_1_1Transformation3D.html#afba85c756d4f1af1f29d1a466854e711", null ],
     [ "~Transformation3D", "classIMP_1_1algebra_1_1Transformation3D.html#a287fb67d5ab03387c8bc55972e249c2d", null ],
     [ "get_inverse", "classIMP_1_1algebra_1_1Transformation3D.html#a11749e8dd0e6454fa96ffb626b39949b", null ],
@@ -12,6 +13,5 @@ var classIMP_1_1algebra_1_1Transformation3D =
     [ "operator*=", "classIMP_1_1algebra_1_1Transformation3D.html#a07bc275d62927745a4eb2df457bbaf12", null ],
     [ "operator/", "classIMP_1_1algebra_1_1Transformation3D.html#ad527f26807df0a9fe8a5aca648d91b4c", null ],
     [ "operator/=", "classIMP_1_1algebra_1_1Transformation3D.html#afe442ff46864a4e9fde422dc62d30047", null ],
-    [ "rot_", "classIMP_1_1algebra_1_1Transformation3D.html#a41c2855af56891c06f8bb083a50ed5f9", null ],
     [ "show", "classIMP_1_1algebra_1_1Transformation3D.html#a0cb9df08c5232d99a8c57fa0c0443c60", null ]
 ];
\ No newline at end of file
