@@ -11,13 +11,10 @@ var classIMP_1_1atom_1_1Bonded =
     [ "get_bond", "classIMP_1_1atom_1_1Bonded.html#ac6814fc8a4b9c0f53afe43fe02b1ea0b", null ],
     [ "get_bond_indexes", "classIMP_1_1atom_1_1Bonded.html#a6d24f4e95a57f542cbd492cc5ad156ea", null ],
     [ "get_bonded", "classIMP_1_1atom_1_1Bonded.html#a3c4e2968dfd4bd247f4661d874d63496", null ],
-    [ "get_bonds", "classIMP_1_1atom_1_1Bonded.html#a5bd234269cc0ecdf545e24807253ea9c", null ],
     [ "get_is_setup", "classIMP_1_1atom_1_1Bonded.html#ab194e1eafa2f3fcde0471b050d642262", null ],
     [ "get_is_setup", "classIMP_1_1atom_1_1Bonded.html#a533a86e427de469baa8ffdbce22a5d69", null ],
     [ "get_number_of_bonds", "classIMP_1_1atom_1_1Bonded.html#a1c4b4847f9f4baa89f9ef1278bcad0a6", null ],
-    [ "particle_is_instance", "classIMP_1_1atom_1_1Bonded.html#aec334a09477bd0b569fbde581b6fbf39", null ],
-    [ "particle_is_instance", "classIMP_1_1atom_1_1Bonded.html#aa33c123ea40d0e9d693d5d9326f04bee", null ],
-    [ "setup_particle", "classIMP_1_1atom_1_1Bonded.html#a5cacba235d9528c7e39044f6b368bd18", null ],
     [ "setup_particle", "classIMP_1_1atom_1_1Bonded.html#a00f95654c5ef950a9a3e70cbd8c36cdd", null ],
+    [ "setup_particle", "classIMP_1_1atom_1_1Bonded.html#a5cacba235d9528c7e39044f6b368bd18", null ],
     [ "show", "classIMP_1_1atom_1_1Bonded.html#a921e9dda7abcdde9b6e8329cd0ac99ac", null ]
 ];
\ No newline at end of file
