@@ -4,19 +4,13 @@ var classIMP_1_1atom_1_1Domain =
     [ "Domain", "classIMP_1_1atom_1_1Domain.html#a60ade3ef83522140c9ab69551a2c11c5", null ],
     [ "Domain", "classIMP_1_1atom_1_1Domain.html#ab4ccdf70c691afc09363f50ea75d01e9", null ],
     [ "decorate_particle", "classIMP_1_1atom_1_1Domain.html#a8767b54a4fec2e1810f938e24353db20", null ],
-    [ "get_begin_index", "classIMP_1_1atom_1_1Domain.html#a62ea9984278bfa54a6080294d4e30fe4", null ],
-    [ "get_end_index", "classIMP_1_1atom_1_1Domain.html#a2103a81bad46237f6198670fd24eb030", null ],
     [ "get_index_range", "classIMP_1_1atom_1_1Domain.html#aa9bbe6e5287146d30569cdc20b3982ef", null ],
     [ "get_is_setup", "classIMP_1_1atom_1_1Domain.html#a8673ff4cc4f8226c9a72788a2a09721a", null ],
     [ "get_is_setup", "classIMP_1_1atom_1_1Domain.html#a2e67229a31777d35b47b4fa0286d12d5", null ],
-    [ "particle_is_instance", "classIMP_1_1atom_1_1Domain.html#a369b39dd522c63333c7563ef21d2d497", null ],
-    [ "particle_is_instance", "classIMP_1_1atom_1_1Domain.html#ad1de22f89b2065a56ab3effb2cc93bb7", null ],
     [ "set_index_range", "classIMP_1_1atom_1_1Domain.html#a165b2016dcef67669fd0de3eeb6e7a00", null ],
-    [ "setup_particle", "classIMP_1_1atom_1_1Domain.html#aa681be58da92a7bcf73c8de91b320d57", null ],
     [ "setup_particle", "classIMP_1_1atom_1_1Domain.html#a3fcce9fba7f9ef896343d54170db2594", null ],
+    [ "setup_particle", "classIMP_1_1atom_1_1Domain.html#aa681be58da92a7bcf73c8de91b320d57", null ],
     [ "setup_particle", "classIMP_1_1atom_1_1Domain.html#a44da187d7acbcac3cdf82df296961f34", null ],
     [ "setup_particle", "classIMP_1_1atom_1_1Domain.html#a8ac34a086134cf685d76368523abf1a0", null ],
-    [ "setup_particle", "classIMP_1_1atom_1_1Domain.html#a85fe187e7726300a3d86e788389b2bcd", null ],
-    [ "setup_particle", "classIMP_1_1atom_1_1Domain.html#a4b3fc93a12c9c0f4f16d1998dcca122d", null ],
     [ "show", "classIMP_1_1atom_1_1Domain.html#abee762ae030ff8cffd3b8343545d3761", null ]
 ];
\ No newline at end of file
