@@ -1,7 +1,7 @@
 var classIMP_1_1atom_1_1RemoveRigidMotionOptimizerState =
 [
-    [ "RemoveRigidMotionOptimizerState", "classIMP_1_1atom_1_1RemoveRigidMotionOptimizerState.html#a1a5f978aebde35ff6831661f19b997b3", null ],
     [ "RemoveRigidMotionOptimizerState", "classIMP_1_1atom_1_1RemoveRigidMotionOptimizerState.html#a8690af4e278d0499caa9e6bbc75bcb38", null ],
+    [ "~RemoveRigidMotionOptimizerState", "classIMP_1_1atom_1_1RemoveRigidMotionOptimizerState.html#abd164dcf161fcec3f67d43ae3d880164", null ],
     [ "do_update", "classIMP_1_1atom_1_1RemoveRigidMotionOptimizerState.html#aa6deb6c44df51583ed464f8b75673b44", null ],
     [ "get_type_name", "classIMP_1_1atom_1_1RemoveRigidMotionOptimizerState.html#a1370a385c9c74a18e930b438192dcea5", null ],
     [ "get_version_info", "classIMP_1_1atom_1_1RemoveRigidMotionOptimizerState.html#aaccd56e35d97c8f59f3acd12d85eb254", null ],
