@@ -2,14 +2,11 @@ var classIMP_1_1base_1_1Memoizer =
 [
     [ "Key", "classIMP_1_1base_1_1Memoizer.html#ad1646162094432b1bd5eadd831812b74", null ],
     [ "Value", "classIMP_1_1base_1_1Memoizer.html#a721d9423f307891bb7ebd9435f2f71f7", null ],
+    [ "Memoizer", "classIMP_1_1base_1_1Memoizer.html#a307e4b913a033c9eac644158953fc4ca", null ],
     [ "access_generator", "classIMP_1_1base_1_1Memoizer.html#a08edb2eb485c1f73c39344e3ae819eb8", null ],
-    [ "checker_", "classIMP_1_1base_1_1Memoizer.html#a704a69caace87de88563651abcefeb0c", null ],
     [ "get", "classIMP_1_1base_1_1Memoizer.html#a1b16d828039bcedbdc9ad3e98844166c", null ],
     [ "get_generator", "classIMP_1_1base_1_1Memoizer.html#a8304a0712ab357a16738c3c2c2111ff5", null ],
     [ "get_hit_rate", "classIMP_1_1base_1_1Memoizer.html#a8ba525be86db5f6fcb21169f10c5b9c0", null ],
-    [ "has_result_", "classIMP_1_1base_1_1Memoizer.html#a9197539575680c3964373d55c8aea09a", null ],
-    [ "num_misses_", "classIMP_1_1base_1_1Memoizer.html#a92b8b8d2686706da9bc98dc951db5c2a", null ],
-    [ "num_stats_", "classIMP_1_1base_1_1Memoizer.html#ad37ed7a64df6409c0ea02e2273598212", null ],
     [ "reset", "classIMP_1_1base_1_1Memoizer.html#aea1a7f1da6af7e2de6402a7d1d8a857c", null ],
     [ "set", "classIMP_1_1base_1_1Memoizer.html#a3b917a7ed82bd0973518356ba07c13bb", null ]
 ];
\ No newline at end of file
