@@ -4,5 +4,5 @@ var classIMP_1_1base_1_1TextOutput =
     [ "TextOutput", "classIMP_1_1base_1_1TextOutput.html#a38ad05b3f7e91abaa74384f17113d93a", null ],
     [ "TextOutput", "classIMP_1_1base_1_1TextOutput.html#a4527df0a4656fe6f4171cccea483a2a7", null ],
     [ "get_name", "classIMP_1_1base_1_1TextOutput.html#a1883250a66b9ffd8faa377927a0afd1d", null ],
-    [ "IMP_SHOWABLE_INLINE", "classIMP_1_1base_1_1TextOutput.html#a5d9dc4523902495539a2b11c82a90a9e", null ]
+    [ "show", "classIMP_1_1base_1_1TextOutput.html#a454fcdb78171f1bbdbe102caa05e75b4", null ]
 ];
\ No newline at end of file
