@@ -4,13 +4,12 @@ var classIMP_1_1core_1_1Centroid =
     [ "Centroid", "classIMP_1_1core_1_1Centroid.html#a7a55b3d9dfe09e567acf2bdfc906d80e", null ],
     [ "Centroid", "classIMP_1_1core_1_1Centroid.html#a79eb8be363343d6484e3d84294984f8c", null ],
     [ "decorate_particle", "classIMP_1_1core_1_1Centroid.html#a53dc5798a559468e5e4c9803c2dd3e2e", null ],
-    [ "get_is_setup", "classIMP_1_1core_1_1Centroid.html#a01e84ba4fd96e667d1402b085d152934", null ],
+    [ "get_constraint", "classIMP_1_1core_1_1Centroid.html#ae00729aa7256523a7ae601d1b04d59b1", null ],
     [ "get_is_setup", "classIMP_1_1core_1_1Centroid.html#a9b2c4ff1fb5d53f4d93e6dce37fb4024", null ],
-    [ "particle_is_instance", "classIMP_1_1core_1_1Centroid.html#a7ed8f0a469ca278429e2b8d2b6dcc22a", null ],
-    [ "particle_is_instance", "classIMP_1_1core_1_1Centroid.html#ad0a4f7a8a5e136a914e70c78070908c0", null ],
-    [ "setup_particle", "classIMP_1_1core_1_1Centroid.html#a5405a29777acbfd6475759d042eb0516", null ],
-    [ "setup_particle", "classIMP_1_1core_1_1Centroid.html#a427b0da4a2a4017864f9de98e9bca714", null ],
-    [ "setup_particle", "classIMP_1_1core_1_1Centroid.html#a3cb848c883d70aa346f6d69ff856a484", null ],
+    [ "get_is_setup", "classIMP_1_1core_1_1Centroid.html#a01e84ba4fd96e667d1402b085d152934", null ],
     [ "setup_particle", "classIMP_1_1core_1_1Centroid.html#a9bfdbc1331708d006ddd14b2c40855e1", null ],
+    [ "setup_particle", "classIMP_1_1core_1_1Centroid.html#a5405a29777acbfd6475759d042eb0516", null ],
+    [ "setup_particle", "classIMP_1_1core_1_1Centroid.html#a3cb848c883d70aa346f6d69ff856a484", null ],
+    [ "setup_particle", "classIMP_1_1core_1_1Centroid.html#a427b0da4a2a4017864f9de98e9bca714", null ],
     [ "show", "classIMP_1_1core_1_1Centroid.html#a824b78a74d4472a9f0206004828bc582", null ]
 ];
\ No newline at end of file
