@@ -4,13 +4,12 @@ var classIMP_1_1core_1_1Cover =
     [ "Cover", "classIMP_1_1core_1_1Cover.html#a727d4998261600ea1caef4f9527ce0a5", null ],
     [ "Cover", "classIMP_1_1core_1_1Cover.html#a61712334f980f0108ad5884db044a7e1", null ],
     [ "decorate_particle", "classIMP_1_1core_1_1Cover.html#a67fc698b80fd73185adf0ca427d1fee0", null ],
-    [ "get_is_setup", "classIMP_1_1core_1_1Cover.html#a594d7ca033d78c7106a7e34a3d689384", null ],
+    [ "get_constraint", "classIMP_1_1core_1_1Cover.html#acbba65724f3b5cc5ccba6230030bb5a7", null ],
     [ "get_is_setup", "classIMP_1_1core_1_1Cover.html#a48242c9323dc8969379e1c91669474ae", null ],
-    [ "particle_is_instance", "classIMP_1_1core_1_1Cover.html#a8179b42de9bffa01bac5be887190717e", null ],
-    [ "particle_is_instance", "classIMP_1_1core_1_1Cover.html#a01b1eabdb3dcb086aa29228bfdf535e0", null ],
-    [ "setup_particle", "classIMP_1_1core_1_1Cover.html#a04f64086ce34072374123d53e48bebee", null ],
-    [ "setup_particle", "classIMP_1_1core_1_1Cover.html#a4ad603f6fb778bef76f967e5c67f1b3f", null ],
-    [ "setup_particle", "classIMP_1_1core_1_1Cover.html#aea1abd021d9a5f8de8673fb8eacee1d8", null ],
+    [ "get_is_setup", "classIMP_1_1core_1_1Cover.html#a594d7ca033d78c7106a7e34a3d689384", null ],
     [ "setup_particle", "classIMP_1_1core_1_1Cover.html#a4f040b20d4c0354d0bbabf61683096b4", null ],
+    [ "setup_particle", "classIMP_1_1core_1_1Cover.html#a04f64086ce34072374123d53e48bebee", null ],
+    [ "setup_particle", "classIMP_1_1core_1_1Cover.html#aea1abd021d9a5f8de8673fb8eacee1d8", null ],
+    [ "setup_particle", "classIMP_1_1core_1_1Cover.html#a4ad603f6fb778bef76f967e5c67f1b3f", null ],
     [ "show", "classIMP_1_1core_1_1Cover.html#a7994ea4260af9498292033f46248821a", null ]
 ];
\ No newline at end of file
