@@ -12,6 +12,7 @@ var classIMP_1_1core_1_1Hierarchy =
     [ "get_child_index", "classIMP_1_1core_1_1Hierarchy.html#afc8f4b8295dfcfd03940905959fa24d1", null ],
     [ "get_child_index", "classIMP_1_1core_1_1Hierarchy.html#a15ee9904d7093e46190d82de10ea3aed", null ],
     [ "get_children", "classIMP_1_1core_1_1Hierarchy.html#aefb5588331333dfcebfc70c714810351", null ],
+    [ "get_children_indexes", "classIMP_1_1core_1_1Hierarchy.html#a102cb65d695eda3395a4fe614dc9030c", null ],
     [ "get_decorator_traits", "classIMP_1_1core_1_1Hierarchy.html#a21ff4285e9aa013c1914f59a54f7b02c", null ],
     [ "get_default_decorator_traits", "classIMP_1_1core_1_1Hierarchy.html#a0c6a95216a6e527ffee2f054faa8cdd6", null ],
     [ "get_default_traits", "classIMP_1_1core_1_1Hierarchy.html#aba2834d7467a9a41e0ba54d7f09044c5", null ],
@@ -20,15 +21,13 @@ var classIMP_1_1core_1_1Hierarchy =
     [ "get_number_of_children", "classIMP_1_1core_1_1Hierarchy.html#a8d84baed8ea1c408f2a82c223099a70c", null ],
     [ "get_parent", "classIMP_1_1core_1_1Hierarchy.html#ac2fb4759f8f6c9b38e1a07f1e7fb5578", null ],
     [ "get_traits", "classIMP_1_1core_1_1Hierarchy.html#ab576c86a2116587699523d583391824b", null ],
-    [ "particle_is_instance", "classIMP_1_1core_1_1Hierarchy.html#ac6cb4d16fb29fe04d19e7f5243051310", null ],
-    [ "particle_is_instance", "classIMP_1_1core_1_1Hierarchy.html#afd08716aac66df7b115ff63b4bf629b7", null ],
     [ "remove_child", "classIMP_1_1core_1_1Hierarchy.html#ad87fd5fa8a40eccbd9521bcf4578a088", null ],
     [ "remove_child", "classIMP_1_1core_1_1Hierarchy.html#ad99b4f19345b28138ee910b6af438426", null ],
-    [ "setup_particle", "classIMP_1_1core_1_1Hierarchy.html#a071bdca8bec3e0429efc652d79883372", null ],
     [ "setup_particle", "classIMP_1_1core_1_1Hierarchy.html#afa445d9465c192c43ade1df6a4871b02", null ],
-    [ "setup_particle", "classIMP_1_1core_1_1Hierarchy.html#a603057a8541c1768f5bc917ac204ad1f", null ],
+    [ "setup_particle", "classIMP_1_1core_1_1Hierarchy.html#a071bdca8bec3e0429efc652d79883372", null ],
     [ "setup_particle", "classIMP_1_1core_1_1Hierarchy.html#a422624be7426817c54942fdff1ce4d77", null ],
-    [ "setup_particle", "classIMP_1_1core_1_1Hierarchy.html#a83a803677b4aa43ad2016e00a1963179", null ],
+    [ "setup_particle", "classIMP_1_1core_1_1Hierarchy.html#a603057a8541c1768f5bc917ac204ad1f", null ],
     [ "setup_particle", "classIMP_1_1core_1_1Hierarchy.html#a7a6c4632c606e31bd882b536ac517e36", null ],
+    [ "setup_particle", "classIMP_1_1core_1_1Hierarchy.html#a83a803677b4aa43ad2016e00a1963179", null ],
     [ "show", "classIMP_1_1core_1_1Hierarchy.html#a455a3cf4007974120234a9faaa051b4b", null ]
 ];
\ No newline at end of file
