@@ -1,16 +1,14 @@
 var classIMP_1_1core_1_1MonteCarloMover =
 [
-    [ "MonteCarloMover", "classIMP_1_1core_1_1MonteCarloMover.html#a62d8aaca00ca1598f3ee81fdf9b6c2fc", null ],
+    [ "MonteCarloMover", "classIMP_1_1core_1_1MonteCarloMover.html#a178a1c2d62fcd260da76dc7afdf1c7b7", null ],
     [ "accept", "classIMP_1_1core_1_1MonteCarloMover.html#ae95f698cb0107d7d3d8c18da29232c07", null ],
     [ "do_accept", "classIMP_1_1core_1_1MonteCarloMover.html#aa8e97296461f1b14f1043bcc94a48b47", null ],
-    [ "do_get_outputs", "classIMP_1_1core_1_1MonteCarloMover.html#a1f8bd06221f43922db94acc4cc10ee2f", null ],
+    [ "do_get_outputs", "classIMP_1_1core_1_1MonteCarloMover.html#ab5a9bca164d18c51263ba1766a40e81b", null ],
     [ "do_propose", "classIMP_1_1core_1_1MonteCarloMover.html#aaa085c84202a79006eef5e1387ab0315", null ],
     [ "do_reject", "classIMP_1_1core_1_1MonteCarloMover.html#aba96371b6d10690911a7a9c8c40943e3", null ],
-    [ "do_update_dependencies", "classIMP_1_1core_1_1MonteCarloMover.html#a9f4bb73b8f53e24b2b2c1e3374a8c25a", null ],
     [ "get_number_of_accepted", "classIMP_1_1core_1_1MonteCarloMover.html#aa1eac9ddce9c90fe546ea0da2e29e515", null ],
     [ "get_number_of_proposed", "classIMP_1_1core_1_1MonteCarloMover.html#a561f20db38bc4243ff6fdb3d9d3654a9", null ],
     [ "propose", "classIMP_1_1core_1_1MonteCarloMover.html#a1d26d9a0f69e959d4bc8e2a7511c4683", null ],
     [ "reject", "classIMP_1_1core_1_1MonteCarloMover.html#ab0dafa32b7e3a8aaff395572930bbbc1", null ],
-    [ "reset_statistics", "classIMP_1_1core_1_1MonteCarloMover.html#a32db55d9144635d08aaa3fc3d279579e", null ],
-    [ "MonteCarloMoversTemp", "classIMP_1_1core_1_1MonteCarloMover.html#a4410d5a4d83312956acbe746f538134a", null ]
+    [ "reset_statistics", "classIMP_1_1core_1_1MonteCarloMover.html#a32db55d9144635d08aaa3fc3d279579e", null ]
 ];
\ No newline at end of file
