@@ -12,21 +12,21 @@ var classIMP_1_1core_1_1RigidBody =
     [ "get_coordinates_are_optimized", "classIMP_1_1core_1_1RigidBody.html#aed5972a76982f506a97571c66572bef1", null ],
     [ "get_is_setup", "classIMP_1_1core_1_1RigidBody.html#a2c395a4a73301b20e1ad26acdbad5486", null ],
     [ "get_is_setup", "classIMP_1_1core_1_1RigidBody.html#ad4024d8ac40d4c14b480f0d2bbf5c341", null ],
+    [ "get_member_indexes", "classIMP_1_1core_1_1RigidBody.html#a0f259e96ce32e2f69a3cdaba83c5e8f2", null ],
     [ "get_member_particle_indexes", "classIMP_1_1core_1_1RigidBody.html#ab1209e9e9104e54642c18021f014b824", null ],
     [ "get_members", "classIMP_1_1core_1_1RigidBody.html#a4fee01a8f48567c5b52d574a4784b006", null ],
     [ "get_reference_frame", "classIMP_1_1core_1_1RigidBody.html#ac13846a110676d06ea4baaa5530f4a49", null ],
+    [ "get_rigid_members", "classIMP_1_1core_1_1RigidBody.html#a01768cb77a2b5321ce1d5c49eb18e77a", null ],
     [ "get_rotational_derivatives", "classIMP_1_1core_1_1RigidBody.html#aa571733d4c574e3874777daef1f10d86", null ],
     [ "get_torque", "classIMP_1_1core_1_1RigidBody.html#a5113ee4808da2d41dd1cb23e6f09db99", null ],
     [ "normalize_rotation", "classIMP_1_1core_1_1RigidBody.html#abdff03f43baa40b269004b1a87af9d66", null ],
-    [ "particle_is_instance", "classIMP_1_1core_1_1RigidBody.html#acb32683d72fcf98bf82c5314e6e14a8f", null ],
-    [ "particle_is_instance", "classIMP_1_1core_1_1RigidBody.html#ad7812837f27553e8171865dd3adf9a9c", null ],
     [ "set_coordinates_are_optimized", "classIMP_1_1core_1_1RigidBody.html#a5b8937771b79790b1ee7e2000640e65f", null ],
     [ "set_is_rigid_member", "classIMP_1_1core_1_1RigidBody.html#a6f7e8dad6fada9708bf755183bb48645", null ],
     [ "set_reference_frame", "classIMP_1_1core_1_1RigidBody.html#a9f4a8f119d07286c0b233f98c2a5eab8", null ],
     [ "set_reference_frame_from_members", "classIMP_1_1core_1_1RigidBody.html#a20b4b3a52cdcf8e4c57df20c5081f943", null ],
     [ "set_reference_frame_lazy", "classIMP_1_1core_1_1RigidBody.html#a16aa0a44a153cc3efe7e7fb54191248e", null ],
-    [ "setup_particle", "classIMP_1_1core_1_1RigidBody.html#aabd4f6c3f08a7c3e24405aab08b1f135", null ],
     [ "setup_particle", "classIMP_1_1core_1_1RigidBody.html#ae678bfb4d66a2934b449f3079989d65e", null ],
+    [ "setup_particle", "classIMP_1_1core_1_1RigidBody.html#aabd4f6c3f08a7c3e24405aab08b1f135", null ],
     [ "setup_particle", "classIMP_1_1core_1_1RigidBody.html#a2d18a7d5d57b5bf9e7d824928c94a88a", null ],
     [ "setup_particle", "classIMP_1_1core_1_1RigidBody.html#a8886b4deabe13472bf227ae012ce2595", null ],
     [ "show", "classIMP_1_1core_1_1RigidBody.html#abd8fee0aedb96f73b6c4170c1a211657", null ],
