@@ -1,14 +1,12 @@
 var classIMP_1_1core_1_1SerialMover =
 [
     [ "SerialMover", "classIMP_1_1core_1_1SerialMover.html#a266d91eb9bc571e97f7135c671cb1da9", null ],
+    [ "~SerialMover", "classIMP_1_1core_1_1SerialMover.html#acfe447f166d140809435cc409597a2ec", null ],
     [ "do_accept", "classIMP_1_1core_1_1SerialMover.html#a8665493ed91bf1acb8b8f163561cabdf", null ],
     [ "do_get_inputs", "classIMP_1_1core_1_1SerialMover.html#ad398f5977c9331701817d5079b99a346", null ],
     [ "do_propose", "classIMP_1_1core_1_1SerialMover.html#a2279be536cedd6665c82a8339f4a2ce2", null ],
     [ "do_reject", "classIMP_1_1core_1_1SerialMover.html#a24f3d39ab4a710008997a2f7c3668a70", null ],
-    [ "get_acceptance_probability", "classIMP_1_1core_1_1SerialMover.html#aecf9ab082469235429b30718c4f2dfeb", null ],
     [ "get_movers", "classIMP_1_1core_1_1SerialMover.html#aba3600374b39c22997a4c534b6e15c90", null ],
-    [ "get_number_of_movers", "classIMP_1_1core_1_1SerialMover.html#af31597e9eaf7cc80991e0d8e754e7df8", null ],
     [ "get_type_name", "classIMP_1_1core_1_1SerialMover.html#a63a5f2a877583bb30d314ba7627dec94", null ],
-    [ "get_version_info", "classIMP_1_1core_1_1SerialMover.html#afff176fbea009601ee6b51e5e583e0a9", null ],
-    [ "reset_acceptance_probabilities", "classIMP_1_1core_1_1SerialMover.html#a3815e7989d1f4ad4039adae35df73571", null ]
+    [ "get_version_info", "classIMP_1_1core_1_1SerialMover.html#afff176fbea009601ee6b51e5e583e0a9", null ]
 ];
\ No newline at end of file
