@@ -1,6 +1,7 @@
 var classIMP_1_1em2d_1_1Fine2DRegistrationRestraint =
 [
-    [ "Fine2DRegistrationRestraint", "classIMP_1_1em2d_1_1Fine2DRegistrationRestraint.html#a0fd2c34de4b6d33c9ce1f6387ed196b1", null ],
+    [ "Fine2DRegistrationRestraint", "classIMP_1_1em2d_1_1Fine2DRegistrationRestraint.html#ae9e202aa133302b645199d134da360c3", null ],
+    [ "~Fine2DRegistrationRestraint", "classIMP_1_1em2d_1_1Fine2DRegistrationRestraint.html#a9388ee75242aab9f93cbeb8ae9782af0", null ],
     [ "do_get_inputs", "classIMP_1_1em2d_1_1Fine2DRegistrationRestraint.html#a2af3f48e3dec2601bade992a60c61b6b", null ],
     [ "get_calls", "classIMP_1_1em2d_1_1Fine2DRegistrationRestraint.html#a9d3fb2222883d85d8c6d98e385d24e32", null ],
     [ "get_final_registration", "classIMP_1_1em2d_1_1Fine2DRegistrationRestraint.html#afb4c39b445aa5ddce88c76bf79cf3292", null ],
@@ -8,5 +9,5 @@ var classIMP_1_1em2d_1_1Fine2DRegistrationRestraint =
     [ "get_version_info", "classIMP_1_1em2d_1_1Fine2DRegistrationRestraint.html#acd2930e268a858dfee95fa2bc7c8e5c3", null ],
     [ "set_subject_image", "classIMP_1_1em2d_1_1Fine2DRegistrationRestraint.html#a04ddb2aa50708a968d1f2064831afdfe", null ],
     [ "setup", "classIMP_1_1em2d_1_1Fine2DRegistrationRestraint.html#a67370df5b0c459a94053130e8a6a07ae", null ],
-    [ "const", "classIMP_1_1em2d_1_1Fine2DRegistrationRestraint.html#acff40c036ad3693a33cf9b7b97addbda", null ]
+    [ "unprotected_evaluate", "classIMP_1_1em2d_1_1Fine2DRegistrationRestraint.html#a07fd5bfb207d11a625a9ef50a0583f72", null ]
 ];
\ No newline at end of file
