@@ -3,7 +3,7 @@ var classIMP_1_1em2d_1_1Image =
     [ "Image", "classIMP_1_1em2d_1_1Image.html#adeea8b942bca7cc8a45789d674560130", null ],
     [ "Image", "classIMP_1_1em2d_1_1Image.html#a9a8af54edd7f1f9cf1fd0595f60c59cf", null ],
     [ "Image", "classIMP_1_1em2d_1_1Image.html#a051c8ca01c41487d6d638a3867854283", null ],
-    [ "destroyed_msg", "classIMP_1_1em2d_1_1Image.html#ae1d93e024261fb03f9918707bed39ac3", null ],
+    [ "~Image", "classIMP_1_1em2d_1_1Image.html#a2d3462adb971e638bd7d486dd89d235d", null ],
     [ "get_data", "classIMP_1_1em2d_1_1Image.html#a8606cf1d83b34b5526e23d9b72fb82c5", null ],
     [ "get_header", "classIMP_1_1em2d_1_1Image.html#a22c35720b110b90c7725b31926902d9b", null ],
     [ "get_min_and_max_values", "classIMP_1_1em2d_1_1Image.html#a5e4c5cd924d82804442b594e2ead9790", null ],
