@@ -2,6 +2,7 @@ var classIMP_1_1em_1_1DensityMap =
 [
     [ "DensityMap", "classIMP_1_1em_1_1DensityMap.html#ad56b873550825f08ed258314d89902e8", null ],
     [ "DensityMap", "classIMP_1_1em_1_1DensityMap.html#abf9a162f4619e31c0a3cbc021d7cb7b0", null ],
+    [ "~DensityMap", "classIMP_1_1em_1_1DensityMap.html#a354c122ab9bd4936faf62129b1e83e38", null ],
     [ "add", "classIMP_1_1em_1_1DensityMap.html#a0f672a08c4e0c77954f1a4aef2b01538", null ],
     [ "allocated_data", "classIMP_1_1em_1_1DensityMap.html#a99c360c91160e1f2c1482df28cb5a02c", null ],
     [ "calc_all_voxel2loc", "classIMP_1_1em_1_1DensityMap.html#a52b4434e9742e3aaea0d2eefa7513f57", null ],
@@ -45,7 +46,6 @@ var classIMP_1_1em_1_1DensityMap =
     [ "pad_margin", "classIMP_1_1em_1_1DensityMap.html#a8f5c966aab9fb6fa41e89500efc7f7e3", null ],
     [ "pick_max", "classIMP_1_1em_1_1DensityMap.html#ad8b6d7f1edcab290e04d6056faf2434c", null ],
     [ "real2float", "classIMP_1_1em_1_1DensityMap.html#a356c5ac79fff64094a9e85be1da6be8b", null ],
-    [ "release", "classIMP_1_1em_1_1DensityMap.html#af6c03439b505f7fcee0f26720022c085", null ],
     [ "reset_all_voxel2loc", "classIMP_1_1em_1_1DensityMap.html#aa0cad480c02507f3222f316d4b4bb2e0", null ],
     [ "reset_data", "classIMP_1_1em_1_1DensityMap.html#a08d52cfea5a71dea1e076f36ac08affb", null ],
     [ "same_dimensions", "classIMP_1_1em_1_1DensityMap.html#aa1bf0fe2dd98afc7cd94e0f441ff38f2", null ],
