@@ -1,7 +1,7 @@
 var classIMP_1_1gsl_1_1Simplex =
 [
     [ "Simplex", "classIMP_1_1gsl_1_1Simplex.html#ab4f87f49b063ef3c2a0e9f8a4abe0b0e", null ],
-    [ "Simplex", "classIMP_1_1gsl_1_1Simplex.html#a7e4ad964c1d37278759b3484b06bafaf", null ],
+    [ "~Simplex", "classIMP_1_1gsl_1_1Simplex.html#a770a5878b94fccfaf9b795b58c8292a1", null ],
     [ "do_optimize", "classIMP_1_1gsl_1_1Simplex.html#a9295622355029f2c3c295e1d12e70307", null ],
     [ "get_type_name", "classIMP_1_1gsl_1_1Simplex.html#afae60a386c6c8a0d4e1f191e4d9d5454", null ],
     [ "get_version_info", "classIMP_1_1gsl_1_1Simplex.html#ad14192012e9214611312a9744de66c3e", null ],
