@@ -7,10 +7,11 @@ var classIMP_1_1isd_1_1GaussianRestraint =
     [ "GaussianRestraint", "classIMP_1_1isd_1_1GaussianRestraint.html#acc25f7fdf315ceba3b4ef884e959b5f0", null ],
     [ "GaussianRestraint", "classIMP_1_1isd_1_1GaussianRestraint.html#a182ffe29233c1d1a1ef8cb556867b8c5", null ],
     [ "GaussianRestraint", "classIMP_1_1isd_1_1GaussianRestraint.html#a15ed1d70056edf790a3e46ff3f3d786d", null ],
+    [ "~GaussianRestraint", "classIMP_1_1isd_1_1GaussianRestraint.html#a57ef8c9ff34b3edfcaef1c8e95dc0a58", null ],
     [ "do_get_inputs", "classIMP_1_1isd_1_1GaussianRestraint.html#a28ec5bff7b41005d34c9ab8d4a5620d1", null ],
     [ "get_chi", "classIMP_1_1isd_1_1GaussianRestraint.html#a0d4f48784d696b4494f8c047095f1772", null ],
     [ "get_probability", "classIMP_1_1isd_1_1GaussianRestraint.html#a952fb8308a7d5d8d8639199ccb456c4b", null ],
     [ "get_type_name", "classIMP_1_1isd_1_1GaussianRestraint.html#abcf95b6de293e1d1cf18acbd00380418", null ],
     [ "get_version_info", "classIMP_1_1isd_1_1GaussianRestraint.html#a3084f6a8d9db67967805701d38dc330f", null ],
-    [ "const", "classIMP_1_1isd_1_1GaussianRestraint.html#ae0091a30db998c7d7a61d3f2d836c5be", null ]
+    [ "unprotected_evaluate", "classIMP_1_1isd_1_1GaussianRestraint.html#a98d42542228704c22b1abeebbc70366d", null ]
 ];
\ No newline at end of file
