@@ -1,6 +1,7 @@
 var classIMP_1_1isd_1_1MarginalHBondRestraint =
 [
     [ "MarginalHBondRestraint", "classIMP_1_1isd_1_1MarginalHBondRestraint.html#a7fc09aebc39ac6751d44b4fa7f2997d2", null ],
+    [ "~MarginalHBondRestraint", "classIMP_1_1isd_1_1MarginalHBondRestraint.html#a9fe9290ebeaffbc309bf55d00b3eed7d", null ],
     [ "add_contribution", "classIMP_1_1isd_1_1MarginalHBondRestraint.html#ab53cc71e064352545db0de0508e9d80c", null ],
     [ "add_contribution", "classIMP_1_1isd_1_1MarginalHBondRestraint.html#a3e7e45bd707ac8ffaa52f80692015fe1", null ],
     [ "do_get_inputs", "classIMP_1_1isd_1_1MarginalHBondRestraint.html#a9e96a0e2d1bac6b3334211b2b582a94c", null ],
@@ -9,5 +10,5 @@ var classIMP_1_1isd_1_1MarginalHBondRestraint =
     [ "get_probability", "classIMP_1_1isd_1_1MarginalHBondRestraint.html#a82a31f1bb047e299f565e87a051e7f2b", null ],
     [ "get_type_name", "classIMP_1_1isd_1_1MarginalHBondRestraint.html#a60d0a12e6cfc48a2c2284a1bee50024c", null ],
     [ "get_version_info", "classIMP_1_1isd_1_1MarginalHBondRestraint.html#ae578be52c1544286efe3b4c563b25131", null ],
-    [ "const", "classIMP_1_1isd_1_1MarginalHBondRestraint.html#a6b6003b98c1925ab7b3db5687243f8b9", null ]
+    [ "unprotected_evaluate", "classIMP_1_1isd_1_1MarginalHBondRestraint.html#a9a5897a72877e30870ed486f56189958", null ]
 ];
\ No newline at end of file
