@@ -1,10 +1,11 @@
 var classIMP_1_1isd_1_1NOERestraint =
 [
     [ "NOERestraint", "classIMP_1_1isd_1_1NOERestraint.html#acfade8076c22cb61d90614b182d5da44", null ],
+    [ "~NOERestraint", "classIMP_1_1isd_1_1NOERestraint.html#a53f0768cbec925254bc48e784b2f235d", null ],
     [ "do_get_inputs", "classIMP_1_1isd_1_1NOERestraint.html#ac4a43a3fd2516da2b9aa7700f431267e", null ],
     [ "get_chi", "classIMP_1_1isd_1_1NOERestraint.html#ae8e0eea03a9d9e5eef209cd50fedb292", null ],
     [ "get_probability", "classIMP_1_1isd_1_1NOERestraint.html#abc1e2082262395419c9a3613658772d8", null ],
     [ "get_type_name", "classIMP_1_1isd_1_1NOERestraint.html#a24deb77601d75108a662cc6656abe81a", null ],
     [ "get_version_info", "classIMP_1_1isd_1_1NOERestraint.html#a2ad4a1886dcfa5bbae6c50dd102f1cc5", null ],
-    [ "const", "classIMP_1_1isd_1_1NOERestraint.html#af4156ccb6479d4280d76e9fd30c29836", null ]
+    [ "unprotected_evaluate", "classIMP_1_1isd_1_1NOERestraint.html#af0fb131a65f91ed4c13e8813f2efa160", null ]
 ];
\ No newline at end of file
