@@ -1,8 +1,9 @@
 var classIMP_1_1isd_1_1WeightRestraint =
 [
     [ "WeightRestraint", "classIMP_1_1isd_1_1WeightRestraint.html#a061fce4a8b58b3a454d262d040a45dae", null ],
+    [ "~WeightRestraint", "classIMP_1_1isd_1_1WeightRestraint.html#abcd500dbb9a3629dfd363d023bba6af2", null ],
     [ "do_get_inputs", "classIMP_1_1isd_1_1WeightRestraint.html#a4a735f6e3eb9ef5e12697e4c64955973", null ],
     [ "get_type_name", "classIMP_1_1isd_1_1WeightRestraint.html#aac91891bdc59c9d7557e2ddc7b9d25c3", null ],
     [ "get_version_info", "classIMP_1_1isd_1_1WeightRestraint.html#acae4a8bf65c031fa18edcd7af834aad3", null ],
-    [ "const", "classIMP_1_1isd_1_1WeightRestraint.html#abf946b3711ee896f9963dc6d8e69f6e0", null ]
+    [ "unprotected_evaluate", "classIMP_1_1isd_1_1WeightRestraint.html#a283e1ac525721241431132c20d9142d6", null ]
 ];
\ No newline at end of file
