@@ -3,5 +3,6 @@ var classIMP_1_1kernel_1_1QuadContainerAdaptor =
     [ "QuadContainerAdaptor", "classIMP_1_1kernel_1_1QuadContainerAdaptor.html#a72cd66589179449b03800be02624e94d", null ],
     [ "QuadContainerAdaptor", "classIMP_1_1kernel_1_1QuadContainerAdaptor.html#a5984ee97a816ccceba6577109ba6255e", null ],
     [ "QuadContainerAdaptor", "classIMP_1_1kernel_1_1QuadContainerAdaptor.html#afc05af2bec0c0ac6e2a6b9611873b973", null ],
-    [ "QuadContainerAdaptor", "classIMP_1_1kernel_1_1QuadContainerAdaptor.html#a89375d8b6e480860c759f60b311a970b", null ]
+    [ "QuadContainerAdaptor", "classIMP_1_1kernel_1_1QuadContainerAdaptor.html#a16f9b08edbe49b9b97744da14c14eba1", null ],
+    [ "set_name_if_default", "classIMP_1_1kernel_1_1QuadContainerAdaptor.html#a3dd9b295a84b0cfe24a4dd552bdb86ae", null ]
 ];
\ No newline at end of file
