@@ -2,6 +2,5 @@ var classIMP_1_1kernel_1_1UnaryFunction =
 [
     [ "UnaryFunction", "classIMP_1_1kernel_1_1UnaryFunction.html#af65743f1d180da85da9eeb89ecbf1b34", null ],
     [ "evaluate", "classIMP_1_1kernel_1_1UnaryFunction.html#a38a77dff2b0c739f2b0a81a36406ad3c", null ],
-    [ "evaluate_with_derivative", "classIMP_1_1kernel_1_1UnaryFunction.html#a4725cdf51b93e1f733bb1fe82049a23a", null ],
-    [ "UnaryFunctionsTemp", "classIMP_1_1kernel_1_1UnaryFunction.html#ab46d0da55f02e8a0bc0dc140177fb491", null ]
+    [ "evaluate_with_derivative", "classIMP_1_1kernel_1_1UnaryFunction.html#a4725cdf51b93e1f733bb1fe82049a23a", null ]
 ];
\ No newline at end of file
