@@ -1,9 +1,10 @@
 var classIMP_1_1modeller_1_1MultipleBinormalRestraint =
 [
     [ "MultipleBinormalRestraint", "classIMP_1_1modeller_1_1MultipleBinormalRestraint.html#a9987b8628825b0f59522a657e8f03d25", null ],
+    [ "~MultipleBinormalRestraint", "classIMP_1_1modeller_1_1MultipleBinormalRestraint.html#a5fb40961128fd91820cf3eb4e9b8b19a", null ],
     [ "add_term", "classIMP_1_1modeller_1_1MultipleBinormalRestraint.html#ab1a685860093cf225410b76ff99e002a", null ],
     [ "do_get_inputs", "classIMP_1_1modeller_1_1MultipleBinormalRestraint.html#aec7c01eb2a702141f9694d6f28f9e118", null ],
     [ "get_type_name", "classIMP_1_1modeller_1_1MultipleBinormalRestraint.html#ace93ab3c33df248cc10316c1b2fea892", null ],
     [ "get_version_info", "classIMP_1_1modeller_1_1MultipleBinormalRestraint.html#a02de9d084e4c56bd4f869321af7fc9aa", null ],
-    [ "const", "classIMP_1_1modeller_1_1MultipleBinormalRestraint.html#a00a119cde5793781dab2232f276bb16f", null ]
+    [ "unprotected_evaluate", "classIMP_1_1modeller_1_1MultipleBinormalRestraint.html#ae9b755b31c8706c89159cd5f5c1c7d46", null ]
 ];
\ No newline at end of file
