@@ -1,6 +1,7 @@
 var classIMP_1_1multifit_1_1ComplementarityRestraint =
 [
     [ "ComplementarityRestraint", "classIMP_1_1multifit_1_1ComplementarityRestraint.html#ae0a9e76a60cba0073db1b172dea600cd", null ],
+    [ "~ComplementarityRestraint", "classIMP_1_1multifit_1_1ComplementarityRestraint.html#af7d46c7bd5fe85b93f3d2bdc71a25b87", null ],
     [ "do_get_inputs", "classIMP_1_1multifit_1_1ComplementarityRestraint.html#a0052a2ef15c55cb30703372d113f9618", null ],
     [ "get_type_name", "classIMP_1_1multifit_1_1ComplementarityRestraint.html#aaccc30c8bae58c78c94d700f53a99f2b", null ],
     [ "get_version_info", "classIMP_1_1multifit_1_1ComplementarityRestraint.html#ad2edb7d57bca5decd70debed08750e7e", null ],
@@ -14,5 +15,5 @@ var classIMP_1_1multifit_1_1ComplementarityRestraint =
     [ "set_maximum_penetration_score", "classIMP_1_1multifit_1_1ComplementarityRestraint.html#af73ad08df0acb0c0d7fdbc415c4d79f1", null ],
     [ "set_maximum_separation", "classIMP_1_1multifit_1_1ComplementarityRestraint.html#a882c153d956b972f12180cf0af3a15c6", null ],
     [ "set_penetration_coefficient", "classIMP_1_1multifit_1_1ComplementarityRestraint.html#af1f5f93747777705e02b93874a2e55c4", null ],
-    [ "const", "classIMP_1_1multifit_1_1ComplementarityRestraint.html#ae5f6f09615e10b4cd354128532e1a3e0", null ]
+    [ "unprotected_evaluate", "classIMP_1_1multifit_1_1ComplementarityRestraint.html#a45e971c271abf590164c0abcfe4a49b1", null ]
 ];
\ No newline at end of file
