@@ -1,10 +1,10 @@
 var classIMP_1_1saxs_1_1Distribution =
 [
     [ "Distribution", "classIMP_1_1saxs_1_1Distribution.html#ab679cafdd144b02c1c2d75c00cfaf515", null ],
-    [ "dist2index", "classIMP_1_1saxs_1_1Distribution.html#a12b08ba0644062be40452f60398f5a12", null ],
     [ "get_bin_size", "classIMP_1_1saxs_1_1Distribution.html#a56de083cc86996615fac8134e6eb6572", null ],
+    [ "get_distance_from_index", "classIMP_1_1saxs_1_1Distribution.html#a8409e65425b293cf6573c82a2dcc6355", null ],
+    [ "get_index_from_distance", "classIMP_1_1saxs_1_1Distribution.html#a8d227fcad10bb001f6bbc36b31e1df25", null ],
     [ "get_max_distance", "classIMP_1_1saxs_1_1Distribution.html#a7cfbad4ea7236130cc335922f79bfc23", null ],
-    [ "index2dist", "classIMP_1_1saxs_1_1Distribution.html#af8e17b10f616e2401c935f3d8b88f5b5", null ],
     [ "init", "classIMP_1_1saxs_1_1Distribution.html#ac55b290ae547b0525eaeb0ac3f4749ae", null ],
     [ "bin_size_", "classIMP_1_1saxs_1_1Distribution.html#afc9f899b85700f259e5ef1586aa53a86", null ],
     [ "max_distance_", "classIMP_1_1saxs_1_1Distribution.html#af513e6290609739b482635612f26b0cd", null ],
