@@ -2,6 +2,7 @@ var classIMP_1_1saxs_1_1Profile =
 [
     [ "Profile", "classIMP_1_1saxs_1_1Profile.html#af59a1da449d660c59d1ba0e420688e2b", null ],
     [ "Profile", "classIMP_1_1saxs_1_1Profile.html#a13a4a73f29bf1da5ed7116eaf22df287", null ],
+    [ "~Profile", "classIMP_1_1saxs_1_1Profile.html#a9e4dff05aaa4890b675d26f52810296d", null ],
     [ "add", "classIMP_1_1saxs_1_1Profile.html#a82536430388b99179eaf494ab3c4a227", null ],
     [ "add", "classIMP_1_1saxs_1_1Profile.html#ad2161d03baaa5af6d03d72b7de77bd49", null ],
     [ "add_entry", "classIMP_1_1saxs_1_1Profile.html#abeda80e91be1e570fa114146b743d437", null ],
@@ -11,8 +12,8 @@ var classIMP_1_1saxs_1_1Profile =
     [ "add_partial_profiles", "classIMP_1_1saxs_1_1Profile.html#a0a1d33df12a2c8468a675327e5d2bb3c", null ],
     [ "background_adjust", "classIMP_1_1saxs_1_1Profile.html#a83d5279ce74b9721145ebd438e7019bf", null ],
     [ "calculate_I0", "classIMP_1_1saxs_1_1Profile.html#adb060b5af5111bd4bc669c15d78b4743", null ],
-    [ "calculate_profile", "classIMP_1_1saxs_1_1Profile.html#a260ff45687fb147d5726249556737435", null ],
-    [ "calculate_profile", "classIMP_1_1saxs_1_1Profile.html#a705b507beee1af3b9b1e84a4703998b3", null ],
+    [ "calculate_profile", "classIMP_1_1saxs_1_1Profile.html#a7899931e7a34c5a37a4ef21c62fd90f8", null ],
+    [ "calculate_profile", "classIMP_1_1saxs_1_1Profile.html#a2bd8791b204014530ae18c90df2bd34b", null ],
     [ "calculate_profile_constant_form_factor", "classIMP_1_1saxs_1_1Profile.html#a5ada436966a8f9da3b681e8515ad843e", null ],
     [ "calculate_profile_partial", "classIMP_1_1saxs_1_1Profile.html#a34ed91e024669079bffb1682aa5e2a25", null ],
     [ "calculate_profile_partial", "classIMP_1_1saxs_1_1Profile.html#aa5389f623987257bd740c30900274d56", null ],
@@ -31,9 +32,9 @@ var classIMP_1_1saxs_1_1Profile =
     [ "get_name", "classIMP_1_1saxs_1_1Profile.html#a8402d2369a85a45ccfa8247652df29a8", null ],
     [ "get_q", "classIMP_1_1saxs_1_1Profile.html#af2a6de58d700d67b8b0b9950aeaaf55e", null ],
     [ "get_type_name", "classIMP_1_1saxs_1_1Profile.html#a191109db9160b6e5cd4a8e222346b574", null ],
-    [ "get_variance", "classIMP_1_1saxs_1_1Profile.html#ae462da372dd8e783df8a610c2cba7532", null ],
     [ "get_version_info", "classIMP_1_1saxs_1_1Profile.html#adaf18a5f0229233c96a131de9a2218d0", null ],
     [ "get_weight", "classIMP_1_1saxs_1_1Profile.html#ad883e391d43bf22388f9bea1268d31e0", null ],
+    [ "init", "classIMP_1_1saxs_1_1Profile.html#a782cce8306c6309453b7954c046f75f8", null ],
     [ "is_uniform_sampling", "classIMP_1_1saxs_1_1Profile.html#a212a0770476e6fb88e397da9ded2b575", null ],
     [ "offset", "classIMP_1_1saxs_1_1Profile.html#a0294a033abb583bd6e36d9cdc79c4c02", null ],
     [ "profile_2_distribution", "classIMP_1_1saxs_1_1Profile.html#af9badf8c5270bd3431674c24fbd7aeae", null ],
@@ -66,6 +67,5 @@ var classIMP_1_1saxs_1_1Profile =
     [ "name_", "classIMP_1_1saxs_1_1Profile.html#a94860d6bee067b549c09e2aff936bd15", null ],
     [ "partial_profiles_", "classIMP_1_1saxs_1_1Profile.html#a1b7eb0f489b7d0bc5faff177deb6b0f5", null ],
     [ "q_", "classIMP_1_1saxs_1_1Profile.html#a98206f86eca618bc32993a74bac9aefc", null ],
-    [ "q_mapping_", "classIMP_1_1saxs_1_1Profile.html#a53b3b4a871fdc6b866c4e635e0d444c7", null ],
-    [ "variances_", "classIMP_1_1saxs_1_1Profile.html#a347a53850c4c01ac6ae177e09a1f40b2", null ]
+    [ "q_mapping_", "classIMP_1_1saxs_1_1Profile.html#a53b3b4a871fdc6b866c4e635e0d444c7", null ]
 ];
\ No newline at end of file
