@@ -15,6 +15,7 @@ var examples =
     [ "atom/rigid_brownian_dynamics.py", "atom_2rigid_brownian_dynamics_8py-example.html", null ],
     [ "atom/score_protein_with_ligand.py", "atom_2score_protein_with_ligand_8py-example.html", null ],
     [ "atom/structure_from_sequence.py", "atom_2structure_from_sequence_8py-example.html", null ],
+    [ "BallMover.py", "BallMover_8py-example.html", null ],
     [ "base/flags.cpp", "base_2flags_8cpp-example.html", null ],
     [ "base/flags.py", "base_2flags_8py-example.html", null ],
     [ "base/log.py", "base_2log_8py-example.html", null ],
@@ -68,6 +69,7 @@ var examples =
     [ "em2d/em_images_conversion.py", "em2d_2em_images_conversion_8py-example.html", null ],
     [ "em2d/optimize_em2d_with_montecarlo.py", "em2d_2optimize_em2d_with_montecarlo_8py-example.html", null ],
     [ "example/range_restriction.py", "example_2range_restriction_8py-example.html", null ],
+    [ "grid.cpp", "grid_8cpp-example.html", null ],
     [ "gsl/simplex.py", "gsl_2simplex_8py-example.html", null ],
     [ "kernel/basic_optimization.py", "kernel_2basic_optimization_8py-example.html", null ],
     [ "kernel/chain.py", "kernel_2chain_8py-example.html", null ],
@@ -82,20 +84,10 @@ var examples =
     [ "modeller/imp_restraints_in_modeller.py", "modeller_2imp_restraints_in_modeller_8py-example.html", null ],
     [ "modeller/load_modeller_model.py", "modeller_2load_modeller_model_8py-example.html", null ],
     [ "modeller/modeller_restraints_in_imp.py", "modeller_2modeller_restraints_in_imp_8py-example.html", null ],
+    [ "multiresolution.py", "multiresolution_8py-example.html", null ],
+    [ "multistate.py", "multistate_8py-example.html", null ],
     [ "parallel/local_distance.py", "parallel_2local_distance_8py-example.html", null ],
     [ "parallel/tasks.py", "parallel_2tasks_8py-example.html", null ],
-    [ "restrainer/basic_display.py", "restrainer_2basic_display_8py-example.html", null ],
-    [ "restrainer/basic_setup.py", "restrainer_2basic_setup_8py-example.html", null ],
-    [ "restrainer/em_restraint.py", "restrainer_2em_restraint_8py-example.html", null ],
-    [ "restrainer/nup84_complex_in_bead_representation.py", "restrainer_2nup84_complex_in_bead_representation_8py-example.html", null ],
-    [ "restrainer/rigid_body_and_excluded_volume_restraint.py", "restrainer_2rigid_body_and_excluded_volume_restraint_8py-example.html", null ],
-    [ "restrainer/saxs_restraint.py", "restrainer_2saxs_restraint_8py-example.html", null ],
-    [ "restrainer/simple_connectivity_on_molecules.py", "restrainer_2simple_connectivity_on_molecules_8py-example.html", null ],
-    [ "restrainer/simple_connectivity_on_rigid_bodies.py", "restrainer_2simple_connectivity_on_rigid_bodies_8py-example.html", null ],
-    [ "restrainer/simple_diameter.py", "restrainer_2simple_diameter_8py-example.html", null ],
-    [ "restrainer/simple_distance.py", "restrainer_2simple_distance_8py-example.html", null ],
-    [ "restrainer/simple_em_fit.py", "restrainer_2simple_em_fit_8py-example.html", null ],
-    [ "restrainer/simple_excluded_volume.py", "restrainer_2simple_excluded_volume_8py-example.html", null ],
     [ "rmf/geometry.py", "rmf_2geometry_8py-example.html", null ],
     [ "rmf/link.py", "rmf_2link_8py-example.html", null ],
     [ "rmf/multiresolution.py", "rmf_2multiresolution_8py-example.html", null ],
@@ -106,5 +98,6 @@ var examples =
     [ "saxs/profile.py", "saxs_2profile_8py-example.html", null ],
     [ "saxs/profile_fit.py", "saxs_2profile_fit_8py-example.html", null ],
     [ "statistics/kmeans.py", "statistics_2kmeans_8py-example.html", null ],
-    [ "statistics/write_a_metric.py", "statistics_2write_a_metric_8py-example.html", null ]
+    [ "statistics/write_a_metric.py", "statistics_2write_a_metric_8py-example.html", null ],
+    [ "temperature_rem.py", "temperature_rem_8py-example.html", null ]
 ];
\ No newline at end of file
