@@ -25,8 +25,6 @@ var group__bond =
       [ "get_order", "classIMP_1_1atom_1_1Bond.html#ab3f97416a81de43d3886a5b72bba0f65", null ],
       [ "get_stiffness", "classIMP_1_1atom_1_1Bond.html#a18c36f0ddbab07a59a0ece43ecc203c6", null ],
       [ "get_type", "classIMP_1_1atom_1_1Bond.html#ae1623a7106640582b8ae9bd34858e8b3", null ],
-      [ "particle_is_instance", "classIMP_1_1atom_1_1Bond.html#a06b964755c3e89525974ee647da33528", null ],
-      [ "particle_is_instance", "classIMP_1_1atom_1_1Bond.html#a792d360bc26ee741f3f7a979d0d9bba7", null ],
       [ "set_length", "classIMP_1_1atom_1_1Bond.html#a77d3d3b85dda83f1afb9b7db0c55072d", null ],
       [ "set_order", "classIMP_1_1atom_1_1Bond.html#af019e8d0d6b88064a505a5c93ca36380", null ],
       [ "set_stiffness", "classIMP_1_1atom_1_1Bond.html#add69ec360fc733f479edaf8d311d378d", null ],
@@ -46,28 +44,27 @@ var group__bond =
       [ "get_bond", "classIMP_1_1atom_1_1Bonded.html#ac6814fc8a4b9c0f53afe43fe02b1ea0b", null ],
       [ "get_bond_indexes", "classIMP_1_1atom_1_1Bonded.html#a6d24f4e95a57f542cbd492cc5ad156ea", null ],
       [ "get_bonded", "classIMP_1_1atom_1_1Bonded.html#a3c4e2968dfd4bd247f4661d874d63496", null ],
-      [ "get_bonds", "classIMP_1_1atom_1_1Bonded.html#a5bd234269cc0ecdf545e24807253ea9c", null ],
       [ "get_is_setup", "classIMP_1_1atom_1_1Bonded.html#ab194e1eafa2f3fcde0471b050d642262", null ],
       [ "get_is_setup", "classIMP_1_1atom_1_1Bonded.html#a533a86e427de469baa8ffdbce22a5d69", null ],
       [ "get_number_of_bonds", "classIMP_1_1atom_1_1Bonded.html#a1c4b4847f9f4baa89f9ef1278bcad0a6", null ],
-      [ "particle_is_instance", "classIMP_1_1atom_1_1Bonded.html#aec334a09477bd0b569fbde581b6fbf39", null ],
-      [ "particle_is_instance", "classIMP_1_1atom_1_1Bonded.html#aa33c123ea40d0e9d693d5d9326f04bee", null ],
-      [ "setup_particle", "classIMP_1_1atom_1_1Bonded.html#a5cacba235d9528c7e39044f6b368bd18", null ],
       [ "setup_particle", "classIMP_1_1atom_1_1Bonded.html#a00f95654c5ef950a9a3e70cbd8c36cdd", null ],
+      [ "setup_particle", "classIMP_1_1atom_1_1Bonded.html#a5cacba235d9528c7e39044f6b368bd18", null ],
       [ "show", "classIMP_1_1atom_1_1Bonded.html#a921e9dda7abcdde9b6e8329cd0ac99ac", null ]
     ] ],
     [ "BondedPairFilter", "classIMP_1_1atom_1_1BondedPairFilter.html", [
       [ "BondedPairFilter", "classIMP_1_1atom_1_1BondedPairFilter.html#ae2c3c59f85a7f4e06a1c91ea059b1852", null ],
+      [ "~BondedPairFilter", "classIMP_1_1atom_1_1BondedPairFilter.html#a09dcbdd1dc3afcd44b3e59099d5a8e1f", null ],
       [ "do_get_inputs", "classIMP_1_1atom_1_1BondedPairFilter.html#ae019b8756c90df8c2d2cb4fe19cb7f45", null ],
       [ "get_type_name", "classIMP_1_1atom_1_1BondedPairFilter.html#a4fabb6a1d39fc547a08f69c3462dcacc", null ],
-      [ "get_value", "classIMP_1_1atom_1_1BondedPairFilter.html#a40396f61c9824533bf9f483ceed0f722", null ],
-      [ "get_value", "classIMP_1_1atom_1_1BondedPairFilter.html#a9ebc22ecf1567b0354fca79dd511a714", null ],
+      [ "get_value", "classIMP_1_1atom_1_1BondedPairFilter.html#a2da3a71b14e9ed32b63bd07d9ccaef60", null ],
+      [ "get_value", "classIMP_1_1atom_1_1BondedPairFilter.html#a87aef4de0f20b70ddc6743337b01c5a5", null ],
       [ "get_value_index", "classIMP_1_1atom_1_1BondedPairFilter.html#a75c2b2f3aa8c79d4c7169b85e334a4ba", null ],
-      [ "get_value_index", "classIMP_1_1atom_1_1BondedPairFilter.html#a226c2b7b5563b26fcebfaff6b696657d", null ],
+      [ "get_value_index", "classIMP_1_1atom_1_1BondedPairFilter.html#ab7d76b03e6d1072a54870128777f789a", null ],
       [ "get_version_info", "classIMP_1_1atom_1_1BondedPairFilter.html#a5f6b632f79583e3e69d4dba91cbcf648", null ]
     ] ],
     [ "BondEndpointsRefiner", "classIMP_1_1atom_1_1BondEndpointsRefiner.html", [
       [ "BondEndpointsRefiner", "classIMP_1_1atom_1_1BondEndpointsRefiner.html#aa625c3f62488ae676c3fdda262fbe29b", null ],
+      [ "~BondEndpointsRefiner", "classIMP_1_1atom_1_1BondEndpointsRefiner.html#ae25314294b7e9c68d0e92d2cea9c6111", null ],
       [ "do_get_inputs", "classIMP_1_1atom_1_1BondEndpointsRefiner.html#ad94833a1f040145775968a914b0f28f6", null ],
       [ "get_can_refine", "classIMP_1_1atom_1_1BondEndpointsRefiner.html#a881add2324125a8d236b332b8fd82f79", null ],
       [ "get_refined", "classIMP_1_1atom_1_1BondEndpointsRefiner.html#a15e350d5bc62ba304febc2c7a1c99bde", null ],
@@ -76,9 +73,9 @@ var group__bond =
     ] ],
     [ "BondPairContainer", "classIMP_1_1atom_1_1BondPairContainer.html", [
       [ "BondPairContainer", "classIMP_1_1atom_1_1BondPairContainer.html#a29746aefa377d639d76290e766cde29a", null ],
+      [ "~BondPairContainer", "classIMP_1_1atom_1_1BondPairContainer.html#ae84e22bad09041033adc4e621fc8f678", null ],
       [ "apply_generic", "classIMP_1_1atom_1_1BondPairContainer.html#a3236baee2783ba1c6e62f275277475da", null ],
       [ "do_apply", "classIMP_1_1atom_1_1BondPairContainer.html#a825b0459698d7501bb5134b708580460", null ],
-      [ "do_before_evaluate", "classIMP_1_1atom_1_1BondPairContainer.html#a84a554f75e2e169499ae1d687c4b2b91", null ],
       [ "do_get_inputs", "classIMP_1_1atom_1_1BondPairContainer.html#ad5769f38cea37741c8d4e443d872333b", null ],
       [ "get_all_possible_indexes", "classIMP_1_1atom_1_1BondPairContainer.html#a23acf10f2633e68d84946ebccc95b5c4", null ],
       [ "get_indexes", "classIMP_1_1atom_1_1BondPairContainer.html#a7462f07787883015c4330d3ec3e4ae66", null ],
@@ -88,10 +85,11 @@ var group__bond =
     ] ],
     [ "BondSingletonScore", "classIMP_1_1atom_1_1BondSingletonScore.html", [
       [ "BondSingletonScore", "classIMP_1_1atom_1_1BondSingletonScore.html#abaa89a38a7990656cce91dde514fbdda", null ],
+      [ "~BondSingletonScore", "classIMP_1_1atom_1_1BondSingletonScore.html#a3afaeef81977eb70b71c4cdbc18b5ab4", null ],
       [ "do_get_inputs", "classIMP_1_1atom_1_1BondSingletonScore.html#aabc0f99a8709f132433132ae74954eea", null ],
-      [ "evaluate_if_good_indexes", "classIMP_1_1atom_1_1BondSingletonScore.html#a28073462a785e286d73780cd519e785b", null ],
+      [ "evaluate_if_good_indexes", "classIMP_1_1atom_1_1BondSingletonScore.html#ad6089666d6fa114e3f6554cb3eb38760", null ],
       [ "evaluate_index", "classIMP_1_1atom_1_1BondSingletonScore.html#ade1e43a036f076d638c1050d2412cf27", null ],
-      [ "evaluate_indexes", "classIMP_1_1atom_1_1BondSingletonScore.html#a23fef30e2ab6b624152f529bd54d42fe", null ],
+      [ "evaluate_indexes", "classIMP_1_1atom_1_1BondSingletonScore.html#afb15c9170d376019812460f41ea56f2f", null ],
       [ "get_type_name", "classIMP_1_1atom_1_1BondSingletonScore.html#a8d836e52678b7af6015ecc8e804f92c1", null ],
       [ "get_unary_function", "classIMP_1_1atom_1_1BondSingletonScore.html#a89a5490a606195d94967444c74017632", null ],
       [ "get_version_info", "classIMP_1_1atom_1_1BondSingletonScore.html#abdc76b9a87703cf0696707ceabcb8aa5", null ]
