@@ -17,8 +17,6 @@ var group__hierarchy =
       [ "get_occupancy_key", "classIMP_1_1atom_1_1Atom.html#a23206834d14400770e23f84be6108e15", null ],
       [ "get_temperature_factor", "classIMP_1_1atom_1_1Atom.html#a212f69c0e725230602eea7cb15fcd873", null ],
       [ "get_temperature_factor_key", "classIMP_1_1atom_1_1Atom.html#ad71038d32f588b37656455e2727e03f5", null ],
-      [ "particle_is_instance", "classIMP_1_1atom_1_1Atom.html#a45a7a6bf15bb3b77e81e1a63b13d731a", null ],
-      [ "particle_is_instance", "classIMP_1_1atom_1_1Atom.html#a8013348c7367df5e3f82ba96421856fb", null ],
       [ "set_atom_type", "classIMP_1_1atom_1_1Atom.html#a8dfcc4758811f77db0c3cac0dc0ed992", null ],
       [ "set_input_index", "classIMP_1_1atom_1_1Atom.html#aa9a01751ea17948ca5cf1646b37d2488", null ],
       [ "set_occupancy", "classIMP_1_1atom_1_1Atom.html#a58cf18897d20af49ad8e83c9eac75be2", null ],
@@ -31,6 +29,7 @@ var group__hierarchy =
     ] ],
     [ "ChildrenRefiner", "classIMP_1_1core_1_1ChildrenRefiner.html", [
       [ "ChildrenRefiner", "classIMP_1_1core_1_1ChildrenRefiner.html#ac93f559610e5324ee059430e86e4b7c0", null ],
+      [ "~ChildrenRefiner", "classIMP_1_1core_1_1ChildrenRefiner.html#ab63470be709553245ce9b29bf52c352d", null ],
       [ "do_get_inputs", "classIMP_1_1core_1_1ChildrenRefiner.html#a42d2912e2491f7bf7fac03c7eaa61602", null ],
       [ "get_can_refine", "classIMP_1_1core_1_1ChildrenRefiner.html#a46d4648ed609952a2a0f8dac017daaca", null ],
       [ "get_refined", "classIMP_1_1core_1_1ChildrenRefiner.html#a742dc731ef07bd773f8db1cdaf714330", null ],
@@ -50,6 +49,7 @@ var group__hierarchy =
       [ "get_child_index", "classIMP_1_1core_1_1Hierarchy.html#afc8f4b8295dfcfd03940905959fa24d1", null ],
       [ "get_child_index", "classIMP_1_1core_1_1Hierarchy.html#a15ee9904d7093e46190d82de10ea3aed", null ],
       [ "get_children", "classIMP_1_1core_1_1Hierarchy.html#aefb5588331333dfcebfc70c714810351", null ],
+      [ "get_children_indexes", "classIMP_1_1core_1_1Hierarchy.html#a102cb65d695eda3395a4fe614dc9030c", null ],
       [ "get_decorator_traits", "classIMP_1_1core_1_1Hierarchy.html#a21ff4285e9aa013c1914f59a54f7b02c", null ],
       [ "get_default_decorator_traits", "classIMP_1_1core_1_1Hierarchy.html#a0c6a95216a6e527ffee2f054faa8cdd6", null ],
       [ "get_default_traits", "classIMP_1_1core_1_1Hierarchy.html#aba2834d7467a9a41e0ba54d7f09044c5", null ],
@@ -58,16 +58,14 @@ var group__hierarchy =
       [ "get_number_of_children", "classIMP_1_1core_1_1Hierarchy.html#a8d84baed8ea1c408f2a82c223099a70c", null ],
       [ "get_parent", "classIMP_1_1core_1_1Hierarchy.html#ac2fb4759f8f6c9b38e1a07f1e7fb5578", null ],
       [ "get_traits", "classIMP_1_1core_1_1Hierarchy.html#ab576c86a2116587699523d583391824b", null ],
-      [ "particle_is_instance", "classIMP_1_1core_1_1Hierarchy.html#ac6cb4d16fb29fe04d19e7f5243051310", null ],
-      [ "particle_is_instance", "classIMP_1_1core_1_1Hierarchy.html#afd08716aac66df7b115ff63b4bf629b7", null ],
       [ "remove_child", "classIMP_1_1core_1_1Hierarchy.html#ad87fd5fa8a40eccbd9521bcf4578a088", null ],
       [ "remove_child", "classIMP_1_1core_1_1Hierarchy.html#ad99b4f19345b28138ee910b6af438426", null ],
-      [ "setup_particle", "classIMP_1_1core_1_1Hierarchy.html#a071bdca8bec3e0429efc652d79883372", null ],
       [ "setup_particle", "classIMP_1_1core_1_1Hierarchy.html#afa445d9465c192c43ade1df6a4871b02", null ],
-      [ "setup_particle", "classIMP_1_1core_1_1Hierarchy.html#a603057a8541c1768f5bc917ac204ad1f", null ],
+      [ "setup_particle", "classIMP_1_1core_1_1Hierarchy.html#a071bdca8bec3e0429efc652d79883372", null ],
       [ "setup_particle", "classIMP_1_1core_1_1Hierarchy.html#a422624be7426817c54942fdff1ce4d77", null ],
-      [ "setup_particle", "classIMP_1_1core_1_1Hierarchy.html#a83a803677b4aa43ad2016e00a1963179", null ],
+      [ "setup_particle", "classIMP_1_1core_1_1Hierarchy.html#a603057a8541c1768f5bc917ac204ad1f", null ],
       [ "setup_particle", "classIMP_1_1core_1_1Hierarchy.html#a7a6c4632c606e31bd882b536ac517e36", null ],
+      [ "setup_particle", "classIMP_1_1core_1_1Hierarchy.html#a83a803677b4aa43ad2016e00a1963179", null ],
       [ "show", "classIMP_1_1core_1_1Hierarchy.html#a455a3cf4007974120234a9faaa051b4b", null ]
     ] ],
     [ "HierarchyCounter", "structIMP_1_1core_1_1HierarchyCounter.html", [
@@ -83,6 +81,7 @@ var group__hierarchy =
     ] ],
     [ "LeavesRefiner", "classIMP_1_1core_1_1LeavesRefiner.html", [
       [ "LeavesRefiner", "classIMP_1_1core_1_1LeavesRefiner.html#ab054bc5b90fd5c7a2906d93f39e7b412", null ],
+      [ "~LeavesRefiner", "classIMP_1_1core_1_1LeavesRefiner.html#a8b4aec5d1ef356f0b6ebf4ac612280d8", null ],
       [ "do_get_inputs", "classIMP_1_1core_1_1LeavesRefiner.html#a3deb0cba5c2cd09d55c58a77e8a701e5", null ],
       [ "get_can_refine", "classIMP_1_1core_1_1LeavesRefiner.html#aecaac2b73136e7de8cb7134e53908523", null ],
       [ "get_refined", "classIMP_1_1core_1_1LeavesRefiner.html#a081798ad59ec6104b1a5644166cb086c", null ],
@@ -110,8 +109,6 @@ var group__hierarchy =
       [ "get_is_setup", "classIMP_1_1atom_1_1Residue.html#a3f6436c153cf148f53a2e78b06029423", null ],
       [ "get_residue_type", "classIMP_1_1atom_1_1Residue.html#ab4ca594e94407184dadbcf3f0fe4f9c7", null ],
       [ "get_residue_type_key", "classIMP_1_1atom_1_1Residue.html#aecf28223c2211790971a5326987aa0cf", null ],
-      [ "particle_is_instance", "classIMP_1_1atom_1_1Residue.html#a48132fc5b7d7029913d89a8deecbcb52", null ],
-      [ "particle_is_instance", "classIMP_1_1atom_1_1Residue.html#a31cf33c7090ffbf617d3d334786e3722", null ],
       [ "set_index", "classIMP_1_1atom_1_1Residue.html#ab9d88dc476ae4d567fa041d7999b9b07", null ],
       [ "set_insertion_code", "classIMP_1_1atom_1_1Residue.html#ad5a93267c7882a9231e2660f15c506bc", null ],
       [ "set_residue_type", "classIMP_1_1atom_1_1Residue.html#aa47d3e8ac5a0f07fc67eea29c60b2792", null ],
