@@ -20,11 +20,11 @@ var namespaceIMP =
     [ "kmeans", "namespaceIMP_1_1kmeans.html", "namespaceIMP_1_1kmeans" ],
     [ "misc", "namespaceIMP_1_1misc.html", "namespaceIMP_1_1misc" ],
     [ "modeller", "namespaceIMP_1_1modeller.html", "namespaceIMP_1_1modeller" ],
+    [ "module_template", "namespaceIMP_1_1module__template.html", null ],
     [ "mpi", "namespaceIMP_1_1mpi.html", "namespaceIMP_1_1mpi" ],
     [ "multifit", "namespaceIMP_1_1multifit.html", "namespaceIMP_1_1multifit" ],
     [ "parallel", "namespaceIMP_1_1parallel.html", "namespaceIMP_1_1parallel" ],
     [ "pepdock", "namespaceIMP_1_1pepdock.html", null ],
-    [ "restrainer", "namespaceIMP_1_1restrainer.html", "namespaceIMP_1_1restrainer" ],
     [ "rmf", "namespaceIMP_1_1rmf.html", "namespaceIMP_1_1rmf" ],
     [ "rotamer", "namespaceIMP_1_1rotamer.html", "namespaceIMP_1_1rotamer" ],
     [ "saxs", "namespaceIMP_1_1saxs.html", "namespaceIMP_1_1saxs" ],
@@ -32,6 +32,5 @@ var namespaceIMP =
     [ "scratch", "namespaceIMP_1_1scratch.html", null ],
     [ "statistics", "namespaceIMP_1_1statistics.html", "namespaceIMP_1_1statistics" ],
     [ "symmetry", "namespaceIMP_1_1symmetry.html", "namespaceIMP_1_1symmetry" ],
-    [ "system", "namespaceIMP_1_1system.html", null ],
     [ "test", "namespaceIMP_1_1test.html", "namespaceIMP_1_1test" ]
 ];
\ No newline at end of file
