@@ -72,6 +72,7 @@ var namespaceIMP_1_1atom =
     [ "NonWaterPDBSelector", "classIMP_1_1atom_1_1NonWaterPDBSelector.html", "classIMP_1_1atom_1_1NonWaterPDBSelector" ],
     [ "NotPDBSelector", "classIMP_1_1atom_1_1NotPDBSelector.html", "classIMP_1_1atom_1_1NotPDBSelector" ],
     [ "NPDBSelector", "classIMP_1_1atom_1_1NPDBSelector.html", "classIMP_1_1atom_1_1NPDBSelector" ],
+    [ "OrientedSoapPairScore", "classIMP_1_1atom_1_1OrientedSoapPairScore.html", "classIMP_1_1atom_1_1OrientedSoapPairScore" ],
     [ "OrPDBSelector", "classIMP_1_1atom_1_1OrPDBSelector.html", "classIMP_1_1atom_1_1OrPDBSelector" ],
     [ "PDBSelector", "classIMP_1_1atom_1_1PDBSelector.html", "classIMP_1_1atom_1_1PDBSelector" ],
     [ "PPDBSelector", "classIMP_1_1atom_1_1PPDBSelector.html", "classIMP_1_1atom_1_1PPDBSelector" ],
@@ -79,6 +80,7 @@ var namespaceIMP_1_1atom =
     [ "ProteinLigandRestraint", "classIMP_1_1atom_1_1ProteinLigandRestraint.html", "classIMP_1_1atom_1_1ProteinLigandRestraint" ],
     [ "RemoveRigidMotionOptimizerState", "classIMP_1_1atom_1_1RemoveRigidMotionOptimizerState.html", "classIMP_1_1atom_1_1RemoveRigidMotionOptimizerState" ],
     [ "RemoveTranslationOptimizerState", "classIMP_1_1atom_1_1RemoveTranslationOptimizerState.html", "classIMP_1_1atom_1_1RemoveTranslationOptimizerState" ],
+    [ "Representation", "classIMP_1_1atom_1_1Representation.html", "classIMP_1_1atom_1_1Representation" ],
     [ "Residue", "classIMP_1_1atom_1_1Residue.html", "classIMP_1_1atom_1_1Residue" ],
     [ "ResidueType", "classIMP_1_1atom_1_1ResidueType.html", null ],
     [ "RigidBodyDiffusion", "classIMP_1_1atom_1_1RigidBodyDiffusion.html", "classIMP_1_1atom_1_1RigidBodyDiffusion" ],
@@ -88,6 +90,8 @@ var namespaceIMP_1_1atom =
     [ "SelectionGeometry", "classIMP_1_1atom_1_1SelectionGeometry.html", "classIMP_1_1atom_1_1SelectionGeometry" ],
     [ "Simulator", "classIMP_1_1atom_1_1Simulator.html", "classIMP_1_1atom_1_1Simulator" ],
     [ "SmoothingFunction", "classIMP_1_1atom_1_1SmoothingFunction.html", "classIMP_1_1atom_1_1SmoothingFunction" ],
+    [ "SoapPairFilter", "classIMP_1_1atom_1_1SoapPairFilter.html", "classIMP_1_1atom_1_1SoapPairFilter" ],
+    [ "State", "classIMP_1_1atom_1_1State.html", "classIMP_1_1atom_1_1State" ],
     [ "StereochemistryPairFilter", "classIMP_1_1atom_1_1StereochemistryPairFilter.html", "classIMP_1_1atom_1_1StereochemistryPairFilter" ],
     [ "VelocityScalingOptimizerState", "classIMP_1_1atom_1_1VelocityScalingOptimizerState.html", "classIMP_1_1atom_1_1VelocityScalingOptimizerState" ],
     [ "WaterPDBSelector", "classIMP_1_1atom_1_1WaterPDBSelector.html", "classIMP_1_1atom_1_1WaterPDBSelector" ],
