@@ -3,6 +3,10 @@ var namespaceIMP_1_1isd =
     [ "Analysis", null, [
       [ "Analysis", "classIMP_1_1isd_1_1Analysis_1_1Analysis.html", "classIMP_1_1isd_1_1Analysis_1_1Analysis" ]
     ] ],
+    [ "demux_trajs", null, [
+      [ "Demuxer", "classIMP_1_1isd_1_1demux__trajs_1_1Demuxer.html", null ],
+      [ "LogHolder", "classIMP_1_1isd_1_1demux__trajs_1_1LogHolder.html", "classIMP_1_1isd_1_1demux__trajs_1_1LogHolder" ]
+    ] ],
     [ "Entry", "namespaceIMP_1_1isd_1_1Entry.html", null ],
     [ "History", "namespaceIMP_1_1isd_1_1History.html", "namespaceIMP_1_1isd_1_1History" ],
     [ "shared_functions", null, [
