@@ -42,12 +42,52 @@ var NAVTREE =
       [ "IMP.kmeans", "md_doxygen_generated_class_example_index.html#class_example_index_kmeans", null ],
       [ "IMP.misc", "md_doxygen_generated_class_example_index.html#class_example_index_misc", null ],
       [ "IMP.modeller", "md_doxygen_generated_class_example_index.html#class_example_index_modeller", null ],
+      [ "IMP.mpi", "md_doxygen_generated_class_example_index.html#class_example_index_mpi", null ],
       [ "IMP.parallel", "md_doxygen_generated_class_example_index.html#class_example_index_parallel", null ],
       [ "IMP.rmf", "md_doxygen_generated_class_example_index.html#class_example_index_rmf", null ],
       [ "IMP.rotamer", "md_doxygen_generated_class_example_index.html#class_example_index_rotamer", null ],
       [ "IMP.saxs", "md_doxygen_generated_class_example_index.html#class_example_index_saxs", null ],
       [ "IMP.score_functor", "md_doxygen_generated_class_example_index.html#class_example_index_score_functor", null ],
-      [ "IMP.statistics", "md_doxygen_generated_class_example_index.html#class_example_index_statistics", null ]
+      [ "IMP.statistics", "md_doxygen_generated_class_example_index.html#class_example_index_statistics", null ],
+      [ "IMP.symmetry", "md_doxygen_generated_class_example_index.html#class_example_index_symmetry", null ]
+    ] ],
+    [ "Design example", "md_doxygen_generated_design_example.html", [
+      [ "Overview", "md_doxygen_generated_design_example.html#designexample", null ],
+      [ "Original Description", "md_doxygen_generated_design_example.html#design_original", [
+        [ "Comments on the original description", "md_doxygen_generated_design_example.html#design_original_comments", null ]
+      ] ],
+      [ "Design Proposal for Reading", "md_doxygen_generated_design_example.html#design_reading", null ],
+      [ "Implementing Scoring as a IMP::Restraint", "md_doxygen_generated_design_example.html#design_restraint", null ],
+      [ "Implementing Scoring as a IMP::PairScore", "md_doxygen_generated_design_example.html#design_score", null ],
+      [ "Some final thoughts", "md_doxygen_generated_design_example.html#design_final", null ]
+    ] ],
+    [ "Developer Guide", "md_doxygen_generated_developer_guide.html", [
+      [ "Developing with IMP", "md_doxygen_generated_developer_guide.html#devguide", null ],
+      [ "Getting around IMP", "md_doxygen_generated_developer_guide.html#devguide_getting_around", null ],
+      [ "Writing new code", "md_doxygen_generated_developer_guide.html#devguide_new_code", [
+        [ "Coding conventions", "md_doxygen_generated_developer_guide.html#devguide_conventions", [
+          [ "Indentation", "md_doxygen_generated_developer_guide.html#devguide_indentation", null ],
+          [ "Names", "md_doxygen_generated_developer_guide.html#devguide_names", null ],
+          [ "Passing and storing data", "md_doxygen_generated_developer_guide.html#devguide_passing", null ],
+          [ "Display", "md_doxygen_generated_developer_guide.html#devguide_display", null ],
+          [ "Errors", "md_doxygen_generated_developer_guide.html#devguide_errors", null ],
+          [ "Namespaces", "md_doxygen_generated_developer_guide.html#devguide_namespace", null ]
+        ] ],
+        [ "Documenting your code", "md_doxygen_generated_developer_guide.html#devguide_documenting", null ],
+        [ "Debugging and testing your code", "md_doxygen_generated_developer_guide.html#devguide_testing", null ],
+        [ "Writing Examples", "md_doxygen_generated_developer_guide.html#devguide_examples", null ],
+        [ "Exporting code to Python", "md_doxygen_generated_developer_guide.html#devguide_swig", null ]
+      ] ],
+      [ "Managing your own module", "md_doxygen_generated_developer_guide.html#devguide_module", null ],
+      [ "Contributing code back to the repository", "md_doxygen_generated_developer_guide.html#devguide_contributing", [
+        [ "Once you have submitted code", "md_doxygen_generated_developer_guide.html#devguide_supporting", null ],
+        [ "Cross platform compatibility", "md_doxygen_generated_developer_guide.html#devguide_cross_platform", [
+          [ "C++ 11", "md_doxygen_generated_developer_guide.html#devguide_cxx11", null ]
+        ] ]
+      ] ],
+      [ "Good programming practices", "md_doxygen_generated_developer_guide.html#devguide_cpp", null ],
+      [ "IMP gotchas", "md_doxygen_generated_developer_guide.html#devguide_gotchas", null ],
+      [ "Further reading", "md_doxygen_generated_developer_guide.html#devguide_further_reading", null ]
     ] ],
     [ "Factory Index", "md_doxygen_generated_factory_index.html", [
       [ "Overview", "md_doxygen_generated_factory_index.html#factory_index", null ],
@@ -66,7 +106,6 @@ var NAVTREE =
       [ "IMP.kinematics", "md_doxygen_generated_factory_index.html#factory_index_kinematics", null ],
       [ "IMP.misc", "md_doxygen_generated_factory_index.html#factory_index_misc", null ],
       [ "IMP.multifit", "md_doxygen_generated_factory_index.html#factory_index_multifit", null ],
-      [ "IMP.restrainer", "md_doxygen_generated_factory_index.html#factory_index_restrainer", null ],
       [ "IMP.rotamer", "md_doxygen_generated_factory_index.html#factory_index_rotamer", null ],
       [ "IMP.saxs", "md_doxygen_generated_factory_index.html#factory_index_saxs", null ],
       [ "IMP.statistics", "md_doxygen_generated_factory_index.html#factory_index_statistics", null ]
@@ -81,110 +120,72 @@ var NAVTREE =
       [ "IMP.domino", "md_doxygen_generated_function_example_index.html#function_example_index_domino", null ],
       [ "IMP.em", "md_doxygen_generated_function_example_index.html#function_example_index_em", null ],
       [ "IMP.em2d", "md_doxygen_generated_function_example_index.html#function_example_index_em2d", null ],
-      [ "IMP.example", "md_doxygen_generated_function_example_index.html#function_example_index_example", null ],
       [ "IMP.kernel", "md_doxygen_generated_function_example_index.html#function_example_index_kernel", null ],
-      [ "IMP.restrainer", "md_doxygen_generated_function_example_index.html#function_example_index_restrainer", null ],
       [ "IMP.rmf", "md_doxygen_generated_function_example_index.html#function_example_index_rmf", null ],
       [ "IMP.saxs", "md_doxygen_generated_function_example_index.html#function_example_index_saxs", null ],
       [ "IMP.statistics", "md_doxygen_generated_function_example_index.html#function_example_index_statistics", null ]
     ] ],
-    [ "Design example", "md__tmp_nightly-build-61576_imp-2_81_81_doc_design_example.html", [
-      [ "Overview", "md__tmp_nightly-build-61576_imp-2_81_81_doc_design_example.html#designexample", null ],
-      [ "Original Description", "md__tmp_nightly-build-61576_imp-2_81_81_doc_design_example.html#design_original", [
-        [ "Comments on the original description", "md__tmp_nightly-build-61576_imp-2_81_81_doc_design_example.html#design_original_comments", null ]
+    [ "Installation", "md_doxygen_generated_installation.html", [
+      [ "Building and installing basics", "md_doxygen_generated_installation.html#installation", null ],
+      [ "Prerequisites", "md_doxygen_generated_installation.html#installation_prereqs", [
+        [ "Getting prerequisites on a Mac", "md_doxygen_generated_installation.html#installation_prereqs_mac", null ],
+        [ "Getting prerequisites on Windows", "md_doxygen_generated_installation.html#installation_prereqs_windows", null ]
       ] ],
-      [ "Design Proposal for Reading", "md__tmp_nightly-build-61576_imp-2_81_81_doc_design_example.html#design_reading", null ],
-      [ "Implementing Scoring as a IMP::Restraint", "md__tmp_nightly-build-61576_imp-2_81_81_doc_design_example.html#design_restraint", null ],
-      [ "Implementing Scoring as a IMP::PairScore", "md__tmp_nightly-build-61576_imp-2_81_81_doc_design_example.html#design_score", null ],
-      [ "Some final thoughts", "md__tmp_nightly-build-61576_imp-2_81_81_doc_design_example.html#design_final", null ]
+      [ "Optional prerequisites", "md_doxygen_generated_installation.html#installation_preqs_optional", null ],
+      [ "Where to go next", "md_doxygen_generated_installation.html#installation_next", null ]
     ] ],
-    [ "Developer Guide", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html", [
-      [ "Developing with IMP", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide", null ],
-      [ "Getting around IMP", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide_getting_around", null ],
-      [ "Writing new code", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide_new_code", [
-        [ "Coding conventions", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide_conventions", [
-          [ "Indentation", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide_indentation", null ],
-          [ "Names", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide_names", null ],
-          [ "Passing and storing data", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide_passing", null ],
-          [ "Display", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide_display", null ],
-          [ "Errors", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide_errors", null ],
-          [ "Namespaces", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide_namespace", null ]
-        ] ],
-        [ "Documenting your code", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide_documenting", null ],
-        [ "Debugging and testing your code", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide_testing", null ],
-        [ "Writing Examples", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide_examples", null ],
-        [ "Exporting code to Python", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide_swig", null ]
+    [ "Introduction", "md_doxygen_generated_introduction.html", [
+      [ "Integrative modeling", "md_doxygen_generated_introduction.html#introduction", [
+        [ "Example modeling efforts", "md_doxygen_generated_introduction.html#introduction_efforts", null ],
+        [ "The four stage process", "md_doxygen_generated_introduction.html#introduction_four_stages", null ]
       ] ],
-      [ "Managing your own module", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide_module", null ],
-      [ "Contributing code back to the repository", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide_contributing", [
-        [ "Once you have submitted code", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide_supporting", null ],
-        [ "Cross platform compatibility", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide_cross_platform", [
-          [ "C++ 11", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide_cxx11", null ]
+      [ "IMP", "md_doxygen_generated_introduction.html#introduction_imp", [
+        [ "Representation: IMP::Model", "md_doxygen_generated_introduction.html#introduction_representation", null ],
+        [ "Decorators", "md_doxygen_generated_introduction.html#introduction_decorators", null ],
+        [ "Representing biological molecules", "md_doxygen_generated_introduction.html#introduction_biomolecules", null ],
+        [ "Containers", "md_doxygen_generated_introduction.html#introduction_containers", null ],
+        [ "Constraints and Invariants", "md_doxygen_generated_introduction.html#introduction_constraints", null ],
+        [ "Scoring", "md_doxygen_generated_introduction.html#introduction_scoring", [
+          [ "Restraints", "md_doxygen_generated_introduction.html#introduction_restraints", null ],
+          [ "Scoring functions", "md_doxygen_generated_introduction.html#introduction_scoring_functions", null ]
+        ] ],
+        [ "Sampling", "md_doxygen_generated_introduction.html#introduction_sampling", [
+          [ "Optimizers", "md_doxygen_generated_introduction.html#introduction_optimizers", null ],
+          [ "Samplers", "md_doxygen_generated_introduction.html#introduction_samplers", null ]
+        ] ],
+        [ "Storing and analysis", "md_doxygen_generated_introduction.html#introduction_analsysis", null ],
+        [ "Modular structure of IMP", "md_doxygen_generated_introduction.html#introduction_modular", null ],
+        [ "Understanding what is going on", "md_doxygen_generated_introduction.html#introduction_understanding", [
+          [ "Logging", "md_doxygen_generated_introduction.html#introduction_logging", null ],
+          [ "Runtime checks", "md_doxygen_generated_introduction.html#introduction_checks", null ]
+        ] ],
+        [ "Conventions", "md_doxygen_generated_introduction.html#introduction_conventions", [
+          [ "Units", "md_doxygen_generated_introduction.html#introduction_units", null ],
+          [ "Names", "md_doxygen_generated_introduction.html#introduction_names", null ],
+          [ "Graphs", "md_doxygen_generated_introduction.html#introduction_graphs", null ],
+          [ "Values and Objects (C++ only)", "md_doxygen_generated_introduction.html#introduction_values", null ],
+          [ "Backwards compatibility and deprecation", "md_doxygen_generated_introduction.html#introduction_backwards", null ]
         ] ]
       ] ],
-      [ "Good programming practices", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide_cpp", null ],
-      [ "IMP gotchas", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide_gotchas", null ],
-      [ "Further reading", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide_further_reading", null ]
+      [ "Where to go next", "md_doxygen_generated_introduction.html#introduction_next", null ]
     ] ],
-    [ "Installation", "md__tmp_nightly-build-61576_imp-2_81_81_doc_installation.html", [
-      [ "Building and installing basics", "md__tmp_nightly-build-61576_imp-2_81_81_doc_installation.html#installation", null ],
-      [ "Prerequisites", "md__tmp_nightly-build-61576_imp-2_81_81_doc_installation.html#installation_prereqs", [
-        [ "Getting prerequisites on a Mac", "md__tmp_nightly-build-61576_imp-2_81_81_doc_installation.html#installation_prereqs_mac", null ],
-        [ "Getting prerequisites on Windows", "md__tmp_nightly-build-61576_imp-2_81_81_doc_installation.html#installation_prereqs_windows", null ]
-      ] ],
-      [ "Optional prerequisites", "md__tmp_nightly-build-61576_imp-2_81_81_doc_installation.html#installation_preqs_optional", null ],
-      [ "Where to go next", "md__tmp_nightly-build-61576_imp-2_81_81_doc_installation.html#installation_next", null ]
+    [ "ChangeLog", "md__tmp_nightly-build-90828_imp-2_82_81_ChangeLog.html", [
+      [ "For IMP 2.2.1", "md__tmp_nightly-build-90828_imp-2_82_81_ChangeLog.html#changelog", null ],
+      [ "For IMP 2.2.0", "md__tmp_nightly-build-90828_imp-2_82_81_ChangeLog.html#changelog_2_2_0", null ],
+      [ "For IMP 2.1.1", "md__tmp_nightly-build-90828_imp-2_82_81_ChangeLog.html#changelog_2_1_1", null ],
+      [ "For IMP 2.1", "md__tmp_nightly-build-90828_imp-2_82_81_ChangeLog.html#changelog_2_1", null ],
+      [ "For IMP 2.0", "md__tmp_nightly-build-90828_imp-2_82_81_ChangeLog.html#changelog_2_0", null ]
     ] ],
-    [ "Introduction", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html", [
-      [ "Integrative modeling", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction", [
-        [ "Example modeling efforts", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_efforts", null ],
-        [ "The four stage process", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_four_stages", null ]
-      ] ],
-      [ "IMP", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_imp", [
-        [ "Representation: IMP::Model", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_representation", null ],
-        [ "Decorators", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_decorators", null ],
-        [ "Representing biological molecules", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_biomolecules", null ],
-        [ "Containers", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_containers", null ],
-        [ "Constraints and Invariants", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_constraints", null ],
-        [ "Scoring", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_scoring", [
-          [ "Restraints", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_restraints", null ],
-          [ "Scoring functions", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_scoring_functions", null ]
-        ] ],
-        [ "Sampling", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_sampling", [
-          [ "Optimizers", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_optimizers", null ],
-          [ "Samplers", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_samplers", null ]
-        ] ],
-        [ "Storing and analysis", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_analsysis", null ],
-        [ "Modular structure of IMP", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_modular", null ],
-        [ "Understanding what is going on", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_understanding", [
-          [ "Logging", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_logging", null ],
-          [ "Runtime checks", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_checks", null ]
-        ] ],
-        [ "Conventions", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_conventions", [
-          [ "Units", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_units", null ],
-          [ "Names", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_names", null ],
-          [ "Graphs", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_graphs", null ],
-          [ "Values and Objects (C++ only)", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_values", null ],
-          [ "Backwards compatibility and deprecation", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_backwards", null ]
-        ] ]
-      ] ],
-      [ "Where to go next", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_next", null ]
+    [ "Tools", "md__tmp_nightly-build-90828_imp-2_82_81_tools_README.html", [
+      [ "Tools", "md__tmp_nightly-build-90828_imp-2_82_81_tools_README.html#dev_tools", null ],
+      [ "Making a module", "md__tmp_nightly-build-90828_imp-2_82_81_tools_README.html#dev_tools_make_module", null ],
+      [ "Formatting your code", "md__tmp_nightly-build-90828_imp-2_82_81_tools_README.html#dev_tools_clang_format", null ],
+      [ "Checking standards", "md__tmp_nightly-build-90828_imp-2_82_81_tools_README.html#dev_tools_check_standards", null ]
     ] ],
-    [ "Mailing lists", "maillists.html", null ],
-    [ "ChangeLog", "md__tmp_nightly-build-61576_imp-2_81_81_ChangeLog.html", [
-      [ "For IMP 2.1.1", "md__tmp_nightly-build-61576_imp-2_81_81_ChangeLog.html#ChangeLog", null ],
-      [ "For IMP 2.0", "md__tmp_nightly-build-61576_imp-2_81_81_ChangeLog.html#changelog_2_0", null ]
-    ] ],
-    [ "Tools", "md__tmp_nightly-build-61576_imp-2_81_81_tools_README.html", [
-      [ "Tools", "md__tmp_nightly-build-61576_imp-2_81_81_tools_README.html#dev_tools", null ],
-      [ "Making a module", "md__tmp_nightly-build-61576_imp-2_81_81_tools_README.html#dev_tools_make_module", null ],
-      [ "Formatting your code", "md__tmp_nightly-build-61576_imp-2_81_81_tools_README.html#dev_tools_clang_format", null ],
-      [ "Checking standards", "md__tmp_nightly-build-61576_imp-2_81_81_tools_README.html#dev_tools_check_standards", null ]
-    ] ],
-    [ "Dependencies", "md__tmp_nightly-build-61576_imp-2_81_81_modules_kernel_doc_dependencies.html", [
-      [ "Overview", "md__tmp_nightly-build-61576_imp-2_81_81_modules_kernel_doc_dependencies.html#dependencies", null ],
-      [ "Dependency graph", "md__tmp_nightly-build-61576_imp-2_81_81_modules_kernel_doc_dependencies.html#dependency_graph", null ],
-      [ "Caching dependencies", "md__tmp_nightly-build-61576_imp-2_81_81_modules_kernel_doc_dependencies.html#dependency_caching", null ]
+    [ "Dependencies", "md__tmp_nightly-build-90828_imp-2_82_81_modules_kernel_doc_dependencies.html", [
+      [ "Overview", "md__tmp_nightly-build-90828_imp-2_82_81_modules_kernel_doc_dependencies.html#dependencies", null ],
+      [ "Dependency graph", "md__tmp_nightly-build-90828_imp-2_82_81_modules_kernel_doc_dependencies.html#dependency_graph", null ],
+      [ "Caching dependencies", "md__tmp_nightly-build-90828_imp-2_82_81_modules_kernel_doc_dependencies.html#dependency_caching", null ]
     ] ],
     [ "EMageFit protocol", "emagefit_protocol.html", [
       [ "Input data", "emagefit_protocol.html#input", null ],
@@ -230,9 +231,9 @@ var NAVTREE =
     [ "Files", null, [
       [ "File List", "files.html", "files" ],
       [ "File Members", "globals.html", [
-        [ "All", "globals.html", "globals_dup" ],
+        [ "All", "globals.html", null ],
         [ "Functions", "globals_func.html", null ],
-        [ "Macros", "globals_defs.html", "globals_defs" ]
+        [ "Macros", "globals_defs.html", null ]
       ] ]
     ] ],
     [ "Examples", "examples.html", "examples" ],
@@ -247,57 +248,58 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 ".html",
-"CoverBond_8h.html",
-"FFToperations_8h.html#ae6185037f9174693f64c885d39c8d19e",
-"Molecule_8h.html",
-"RestraintsScoringFunction_8h.html",
-"SurfaceShellDensityMap_8h.html",
-"algebra_2io_8h.html#a2b99092e2bf90a45ecee7ab1208b4dc8",
-"base_2comparison__macros_8h.html#a52aa3e61bdedab02f71543e8cb1de955",
-"base_2types_8h.html#a9119e3460d39dff9761c6eb52771d239",
-"classIMP_1_1algebra_1_1ExtendedGridIndexD.html#ab90c83a96c245844c2b39b4dc800eba8",
-"classIMP_1_1algebra_1_1UnboundedGridRangeD.html#a2d03a2c341ea6a4ec2ac9c76c73d2a3e",
-"classIMP_1_1atom_1_1CAlphaPDBSelector.html#a3e742f95aa37613f7912439b042d9b74",
-"classIMP_1_1atom_1_1CoverBond.html#a2c4edb0d15faceaa62203407c236c364",
-"classIMP_1_1atom_1_1MolecularDynamics.html#a1669840db3ed8c46c89174fd9f5f7de1",
-"classIMP_1_1atom_1_1SmoothingFunction.html",
-"classIMP_1_1benchmark_1_1Profiler.html#ae3c30b3911cf8d407938f1d8dc633577",
-"classIMP_1_1container_1_1InContainerPairFilter.html#a9b8e647990965e0793a114ad30661a86",
-"classIMP_1_1container_1_1QuadsOptimizerState.html#a7ee36b416f2bccf110073e248638a4ab",
-"classIMP_1_1core_1_1CoinFlipPairPredicate.html#ab3ca58396a02e1c75061066b7aa8b83f",
-"classIMP_1_1core_1_1HarmonicLowerBound.html#a460a9abed037efb975e249d271c590ab",
-"classIMP_1_1core_1_1MonteCarloMover.html#ab5a9bca164d18c51263ba1766a40e81b",
-"classIMP_1_1core_1_1RigidBodyDistancePairScore.html",
-"classIMP_1_1core_1_1UnorderedTypeTripletPredicate.html#ab5301f6580c0ca6c05af00a00c339685",
-"classIMP_1_1display_1_1PointGeometry.html",
-"classIMP_1_1domino_1_1DominoSampler.html#abede395fe6fc5abb408c9c3b2b24eb22",
-"classIMP_1_1domino_1_1Subset.html",
-"classIMP_1_1em2d_1_1ImageReaderWriter.html#acdc118dbb9ccf187f29072010f4e71d6",
-"classIMP_1_1em2d_1_1RelativePositionMover.html",
-"classIMP_1_1em_1_1DensityHeader.html#af813b077010999ee8cb4e6c205f97ea0",
-"classIMP_1_1em_1_1ImageHeader.html#ae65ea9249d1d3c6265b14bdf1343cfd7",
-"classIMP_1_1gsl_1_1GSLOptimizer.html#a217dc5ae983b5a3812cdce6f5a958175",
-"classIMP_1_1isd_1_1GeneralizedGuinierPorodFunction.html#a744a9d605b061b085b41da307f0edddf",
-"classIMP_1_1isd_1_1Switching.html#ac7d2bc9a6f56684b3995daca9353414a",
-"classIMP_1_1kernel_1_1GenericScopedRestraint.html#a4eae685b7d6f2d4aa3720c681c320cbd",
-"classIMP_1_1kernel_1_1ParticleIndexesAdaptor.html#a547d9cb2b29ad4010f103164e6c391c2",
-"classIMP_1_1kernel_1_1SingletonPredicate.html#af1a8f49de6be56b17fb93279515ef678",
-"classIMP_1_1kmeans_1_1KMeans.html#aaf2c31bf490f236ede8336a29fb19f1d",
-"classIMP_1_1multifit_1_1DensityDataPoints.html#a4acef994be7098ef06fae54f7a0d1ce5",
-"classIMP_1_1multifit_1_1ProteomicsData.html#a90b8dbbd8e84b9555ffad3edf41ad67f",
-"classIMP_1_1rmf_1_1SaveOptimizerState.html#a5d9352382c753791edb93021ce683f7c",
-"classIMP_1_1score__functor_1_1DistancePairScore.html#a8606f47228c4ed5f06a20a13371cf799",
-"collision__cross__section_8py_source.html",
-"declare__Geometry_8h.html#a105bcdb7fdeef18b628e64889c4bf0ca",
-"em2d_2____init_____8py_source.html",
-"group__bond.html#gad928d4afc3de5646070a1a55499772d3",
-"kernel_2RestraintSet_8h.html#af9fb5d47470a616b0b6e0f8e9068b7d0",
-"kernel_2doxygen_8h.html#a5d38b811b7ce661cb76a33d9434a49e0",
-"kmeans_2KMeans_8h.html#a1b6db7066473f34b4385e2b5ecfe9547a1e3b4c7fb2b2a03ed9925f2e2fa3f022",
-"mol2_8h.html",
-"particle__states_8h.html#a3654515ddd4ebdfdcb88549835351267",
-"scores2D_8h.html#a44fe26f303260f075ccda58b350fe8a0",
-"structIMP_1_1kernel_1_1FloatIndex.html#afe1ec480b21ee09167ddb62bb66bbb58"
+"CoulombPairScore_8h_source.html",
+"FFToperations_8h.html#a8c8e930b89742e1e8793afaee0c828fd",
+"MinimumTripletScore_8h_source.html",
+"Residue_8h.html#a6bf9912d67e4c9d6a134930015a928de",
+"SpiderImageReaderWriter_8h_source.html",
+"algebra_2__version__check_8py_source.html",
+"base_2VersionInfo_8h.html",
+"base_2swap__macros_8h.html#acd974b2e930c1387663c5ce0499e1ebd",
+"classIMP_1_1algebra_1_1DenseGridStorageD.html#a95445265bfccd1afc291a20d19b07649",
+"classIMP_1_1algebra_1_1SparseGridStorageD.html#a4aa29c36e140969aace36148cdca3281",
+"classIMP_1_1atom_1_1Bond.html#a8a5ba84484e72d168d03b0ab4c50c77e",
+"classIMP_1_1atom_1_1CHARMMStereochemistryRestraint.html",
+"classIMP_1_1atom_1_1Hierarchy.html#a4c26db6d0879ccf5d7fc72c30e9ec54e",
+"classIMP_1_1atom_1_1Residue.html#aecf28223c2211790971a5326987aa0cf",
+"classIMP_1_1base_1_1InputAdaptor.html",
+"classIMP_1_1container_1_1ClosePairContainer.html#a2c0a996ffae03083bc03de63c2c1ab08",
+"classIMP_1_1container_1_1ListTripletContainer.html#a5543bae22eb1347648fe6089be5cd1dd",
+"classIMP_1_1container_1_1SingletonContainerStatistics.html#a1ed98045a07347769f94c032ce36ff65",
+"classIMP_1_1core_1_1CoinFlipPairPredicate.html#ab24dfddf37ff124ced1a1ed5b5bdf709",
+"classIMP_1_1core_1_1GenericBoundingBox3DSingletonScore.html#aa0cd2b6a2c77a30b318013960d20948f",
+"classIMP_1_1core_1_1MinimumRestraint.html#ac0eed41add2846906ba37482ba5833f2",
+"classIMP_1_1core_1_1Reference.html#afd3151a3eacc75acfc28dad5d062baf3",
+"classIMP_1_1core_1_1TransformedDistancePairScore.html#af31f1dbc1a08962f44060d7e8c0c8862",
+"classIMP_1_1display_1_1EllipsoidGeometry.html#a0a7e9daf346fa0f226224d14b9e933e7",
+"classIMP_1_1domino_1_1AssignmentContainer.html#aa0d8e3d96ae816d7a6462666ec8c0d04",
+"classIMP_1_1domino_1_1PermutationStates.html#a72f522072259cfda0d15123326d896e7",
+"classIMP_1_1em2d_1_1DistanceFilterTable.html#ae86e7a59f864e1882f116a11e126044b",
+"classIMP_1_1em2d_1_1ProjectionFinder.html#a835b3dcc9f09dab5035f142e602af5e7",
+"classIMP_1_1em2d_1_1solutions__io_1_1ResultsDB.html#a9a9d966238ec2255355b34efca871874",
+"classIMP_1_1em_1_1EnvelopePenetrationRestraint.html#a73bcd18c899decbe79668687052339f2",
+"classIMP_1_1em_1_1SampledDensityMap.html#a21225da3a0ff897533b83534270b1b2b",
+"classIMP_1_1isd_1_1CrossLinkData.html#a8a8bbaac5b35a0b0da2a6987967cee8f",
+"classIMP_1_1isd_1_1MarginalHBondRestraint.html#a9fe9290ebeaffbc309bf55d00b3eed7d",
+"classIMP_1_1isd_1_1WeightRestraint.html#a061fce4a8b58b3a454d262d040a45dae",
+"classIMP_1_1kernel_1_1Optimizer.html#aafc2e263cfd8aa0157ae71f827f19755",
+"classIMP_1_1kernel_1_1RestraintsAdaptor.html",
+"classIMP_1_1kinematics_1_1KinematicForest.html#a35103e7f5bb31a571e30965ec39e3ae3",
+"classIMP_1_1mpi_1_1ReplicaExchange.html#a8da36aa5da3659ed92ec90ed721f0a2c",
+"classIMP_1_1multifit_1_1FittingSolutionRecord.html#a48876faf7d8e726424edf9a19360669e",
+"classIMP_1_1multifit_1_1SettingsData.html#a724e35ef819b0ec71aded7b0059722a4",
+"classIMP_1_1saxs_1_1Profile.html#abddecb7d710dddeffed89858d17d7f80",
+"classIMP_1_1statistics_1_1PartitionalClusteringWithCenter.html",
+"container__base_8h.html",
+"element_8h.html#a611e6343bbcfccda53cc687bd1b23845a61888bc77560e0a7fa93eb545fb7b44f",
+"functions_w.html",
+"kernel_2Constraint_8h.html#a93193609ed13a7b61f9fa802e1137f76",
+"kernel_2dependency__graph_8h.html#a8963d9f8d3757f130f4824de9e3eb113",
+"md_doxygen_generated_argument_index.html#argument_index_isd",
+"namespaceIMP_1_1example.html",
+"protein__anchors__mapping__reader_8h.html#adbd924144aee36a0b6dd9789ca164da8",
+"structIMP_1_1atom_1_1CHARMMDihedralParameters.html#a6988c49cb03aff797ef1804f845842cb",
+"univariate__functions_8h.html"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
@@ -410,7 +412,7 @@ function createIndent(o,domNode,node,level)
     span.style.display = 'inline-block';
     span.style.width   = 16*(level+1)+'px';
     span.style.height  = '22px';
-    span.innerHTML = '&nbsp;';
+    span.innerHTML = '&#160;';
     domNode.appendChild(span);
   } 
 }
