@@ -9,9 +9,11 @@ var vector__generators_8h =
     [ "get_random_vector_in", "vector__generators_8h.html#a0c132a833a6f30793378bbed6dfb8f65", null ],
     [ "get_random_vector_on", "vector__generators_8h.html#a1d68a09215054f5656feb5c310a9e9e0", null ],
     [ "get_random_vector_on", "vector__generators_8h.html#a5cee60da7af2c8bdb9939983e71b4c40", null ],
+    [ "get_random_vector_on_unit_sphere", "vector__generators_8h.html#a15788395c438b5a87b99281375c9e1e7", null ],
     [ "get_uniform_surface_cover", "vector__generators_8h.html#ae70c5237b41e2f094e952fd1298e2e2a", null ],
     [ "get_uniform_surface_cover", "vector__generators_8h.html#a991a576bd3cb05927a2cf4b0089f9d56", null ],
     [ "get_uniform_surface_cover", "vector__generators_8h.html#a72ff2a60e8a826fcc1914fba3552f359", null ],
     [ "get_uniform_surface_cover", "vector__generators_8h.html#a87c353d6dce6da5d919b552792b88c46", null ],
+    [ "get_uniform_surface_cover", "vector__generators_8h.html#a4140479bd360f14cb9edd70534b34a75", null ],
     [ "get_uniform_upper_hemisphere_cover", "vector__generators_8h.html#a3d0722a9b5c0e62dbca7cd5f65fbb738", null ]
 ];
\ No newline at end of file
